# This file is auto-generated by pyrandyos/gui/icons/update_from_spec.py  # noqa: E501
# Do not edit.
_0 = 48
_1 = 49
_2 = 50
_3 = 51
_4 = 52
_5 = 53
_6 = 54
_7 = 55
_8 = 56
_9 = 57
a = 65
address_book = 62137
address_card = 62139
align_center = 61495
align_justify = 61497
align_left = 61494
align_right = 61496
anchor = 61757
anchor_circle_check = 58538
anchor_circle_exclamation = 58539
anchor_circle_xmark = 58540
anchor_lock = 58541
angle_down = 61703
angle_left = 61700
angle_right = 61701
angle_up = 61702
angles_down = 61699
angles_left = 61696
angles_right = 61697
angles_up = 61698
ankh = 63044
apple_whole = 62929
archway = 62807
arrow_down = 61539
arrow_down_1_9 = 61794
arrow_down_9_1 = 63622
arrow_down_a_z = 61789
arrow_down_long = 61813
arrow_down_short_wide = 63620
arrow_down_up_across_line = 58543
arrow_down_up_lock = 58544
arrow_down_wide_short = 61792
arrow_down_z_a = 63617
arrow_left = 61536
arrow_left_long = 61815
arrow_pointer = 62021
arrow_right = 61537
arrow_right_arrow_left = 61676
arrow_right_from_bracket = 61579
arrow_right_long = 61816
arrow_right_to_bracket = 61584
arrow_right_to_city = 58547
arrow_rotate_left = 61666
arrow_rotate_right = 61470
arrow_trend_down = 57495
arrow_trend_up = 57496
arrow_turn_down = 61769
arrow_turn_up = 61768
arrow_up = 61538
arrow_up_1_9 = 61795
arrow_up_9_1 = 63623
arrow_up_a_z = 61790
arrow_up_from_bracket = 57498
arrow_up_from_ground_water = 58549
arrow_up_from_water_pump = 58550
arrow_up_long = 61814
arrow_up_right_dots = 58551
arrow_up_right_from_square = 61582
arrow_up_short_wide = 63621
arrow_up_wide_short = 61793
arrow_up_z_a = 63618
arrows_down_to_line = 58552
arrows_down_to_people = 58553
arrows_left_right = 61566
arrows_left_right_to_line = 58554
arrows_rotate = 61473
arrows_spin = 58555
arrows_split_up_and_left = 58556
arrows_to_circle = 58557
arrows_to_dot = 58558
arrows_to_eye = 58559
arrows_turn_right = 58560
arrows_turn_to_dots = 58561
arrows_up_down = 61565
arrows_up_down_left_right = 61511
arrows_up_to_line = 58562
asterisk = 42
at = 64
atom = 62930
audio_description = 62110
austral_sign = 57513
award = 62809
b = 66
baby = 63356
baby_carriage = 63357
backward = 61514
backward_fast = 61513
backward_step = 61512
bacon = 63461
bacteria = 57433
bacterium = 57434
bag_shopping = 62096
bahai = 63078
baht_sign = 57516
ban = 61534
ban_smoking = 62797
bandage = 62562
bangladeshi_taka_sign = 58086
barcode = 61482
bars = 61641
bars_progress = 63528
bars_staggered = 62800
baseball = 62515
baseball_bat_ball = 62514
basket_shopping = 62097
basketball = 62516
bath = 62157
battery_empty = 62020
battery_full = 62016
battery_half = 62018
battery_quarter = 62019
battery_three_quarters = 62017
bed = 62006
bed_pulse = 62599
beer_mug_empty = 61692
bell = 61683
bell_concierge = 62818
bell_slash = 61942
bezier_curve = 62811
bicycle = 61958
binoculars = 61925
biohazard = 63360
bitcoin_sign = 57524
blender = 62743
blender_phone = 63158
blog = 63361
bold = 61490
bolt = 61671
bolt_lightning = 57527
bomb = 61922
bone = 62935
bong = 62812
book = 61485
book_atlas = 62808
book_bible = 63047
book_bookmark = 57531
book_journal_whills = 63082
book_medical = 63462
book_open = 62744
book_open_reader = 62938
book_quran = 63111
book_skull = 63159
book_tanakh = 63527
bookmark = 61486
border_all = 63564
border_none = 63568
border_top_left = 63571
bore_hole = 58563
bottle_droplet = 58564
bottle_water = 58565
bowl_food = 58566
bowl_rice = 58091
bowling_ball = 62518
box = 62566
box_archive = 61831
box_open = 62622
box_tissue = 57435
boxes_packing = 58567
boxes_stacked = 62568
braille = 62113
brain = 62940
brazilian_real_sign = 58476
bread_slice = 63468
bridge = 58568
bridge_circle_check = 58569
bridge_circle_exclamation = 58570
bridge_circle_xmark = 58571
bridge_lock = 58572
bridge_water = 58574
briefcase = 61617
briefcase_medical = 62569
broom = 62746
broom_ball = 62552
brush = 62813
bucket = 58575
bug = 61832
bug_slash = 58512
bugs = 58576
building = 61869
building_circle_arrow_right = 58577
building_circle_check = 58578
building_circle_exclamation = 58579
building_circle_xmark = 58580
building_columns = 61852
building_flag = 58581
building_lock = 58582
building_ngo = 58583
building_shield = 58584
building_un = 58585
building_user = 58586
building_wheat = 58587
bullhorn = 61601
bullseye = 61760
burger = 63493
burst = 58588
bus = 61959
bus_simple = 62814
business_time = 63050
c = 67
cable_car = 63450
cake_candles = 61949
calculator = 61932
calendar = 61747
calendar_check = 62068
calendar_day = 63363
calendar_days = 61555
calendar_minus = 62066
calendar_plus = 62065
calendar_week = 63364
calendar_xmark = 62067
camera = 61488
camera_retro = 61571
camera_rotate = 57560
campground = 63163
candy_cane = 63366
cannabis = 62815
capsules = 62571
car = 61881
car_battery = 62943
car_burst = 62945
car_on = 58589
car_rear = 62942
car_side = 62948
car_tunnel = 58590
caravan = 63743
caret_down = 61655
caret_left = 61657
caret_right = 61658
caret_up = 61656
carrot = 63367
cart_arrow_down = 61976
cart_flatbed = 62580
cart_flatbed_suitcase = 62877
cart_plus = 61975
cart_shopping = 61562
cash_register = 63368
cat = 63166
cedi_sign = 57567
cent_sign = 58357
certificate = 61603
chair = 63168
chalkboard = 62747
chalkboard_user = 62748
champagne_glasses = 63391
charging_station = 62951
chart_area = 61950
chart_bar = 61568
chart_column = 57571
chart_diagram = 59029
chart_gantt = 57572
chart_line = 61953
chart_pie = 61952
chart_simple = 58483
check = 61452
check_double = 62816
check_to_slot = 63346
cheese = 63471
chess = 62521
chess_bishop = 62522
chess_board = 62524
chess_king = 62527
chess_knight = 62529
chess_pawn = 62531
chess_queen = 62533
chess_rook = 62535
chevron_down = 61560
chevron_left = 61523
chevron_right = 61524
chevron_up = 61559
child = 61870
child_combatant = 58592
child_dress = 58780
child_reaching = 58781
children = 58593
church = 62749
circle = 61713
circle_arrow_down = 61611
circle_arrow_left = 61608
circle_arrow_right = 61609
circle_arrow_up = 61610
circle_check = 61528
circle_chevron_down = 61754
circle_chevron_left = 61751
circle_chevron_right = 61752
circle_chevron_up = 61753
circle_dollar_to_slot = 62649
circle_dot = 61842
circle_down = 62296
circle_exclamation = 61546
circle_h = 62590
circle_half_stroke = 61506
circle_info = 61530
circle_left = 62297
circle_minus = 61526
circle_nodes = 58594
circle_notch = 61902
circle_pause = 62091
circle_play = 61764
circle_plus = 61525
circle_question = 61529
circle_radiation = 63418
circle_right = 62298
circle_stop = 62093
circle_up = 62299
circle_user = 62141
circle_xmark = 61527
city = 63055
clapperboard = 57649
clipboard = 62248
clipboard_check = 62572
clipboard_list = 62573
clipboard_question = 58595
clipboard_user = 63475
clock = 61463
clock_rotate_left = 61914
clone = 62029
closed_captioning = 61962
cloud = 61634
cloud_arrow_down = 61677
cloud_arrow_up = 61678
cloud_bolt = 63340
cloud_meatball = 63291
cloud_moon = 63171
cloud_moon_rain = 63292
cloud_rain = 63293
cloud_showers_heavy = 63296
cloud_showers_water = 58596
cloud_sun = 63172
cloud_sun_rain = 63299
clover = 57657
code = 61729
code_branch = 61734
code_commit = 62342
code_compare = 57658
code_fork = 57659
code_merge = 62343
code_pull_request = 57660
coins = 62750
colon_sign = 57664
comment = 61557
comment_dollar = 63057
comment_dots = 62637
comment_medical = 63477
comment_nodes = 59030
comment_slash = 62643
comment_sms = 63437
comments = 61574
comments_dollar = 63059
compact_disc = 62751
compass = 61774
compass_drafting = 62824
compress = 61542
computer = 58597
computer_mouse = 63692
cookie = 62819
cookie_bite = 62820
copy = 61637
copyright = 61945
couch = 62648
cow = 63176
credit_card = 61597
crop = 61733
crop_simple = 62821
cross = 63060
crosshairs = 61531
crow = 62752
crown = 62753
crutch = 63479
cruzeiro_sign = 57682
cube = 61874
cubes = 61875
cubes_stacked = 58598
d = 68
database = 61888
delete_left = 62810
democrat = 63303
desktop = 62352
dharmachakra = 63061
diagram_next = 58486
diagram_predecessor = 58487
diagram_project = 62786
diagram_successor = 58490
diamond = 61977
diamond_turn_right = 62955
dice = 62754
dice_d20 = 63183
dice_d6 = 63185
dice_five = 62755
dice_four = 62756
dice_one = 62757
dice_six = 62758
dice_three = 62759
dice_two = 62760
disease = 63482
display = 57699
divide = 62761
dna = 62577
dog = 63187
dollar_sign = 36
dolly = 62578
dong_sign = 57705
door_closed = 62762
door_open = 62763
dove = 62650
down_left_and_up_right_to_center = 62498
down_long = 62217
download = 61465
dragon = 63189
draw_polygon = 62958
droplet = 61507
droplet_slash = 62919
drum = 62825
drum_steelpan = 62826
drumstick_bite = 63191
dumbbell = 62539
dumpster = 63379
dumpster_fire = 63380
dungeon = 63193
e = 69
ear_deaf = 62116
ear_listen = 62114
earth_africa = 62844
earth_americas = 62845
earth_asia = 62846
earth_europe = 63394
earth_oceania = 58491
egg = 63483
eject = 61522
elevator = 57709
ellipsis = 61761
ellipsis_vertical = 61762
envelope = 61664
envelope_circle_check = 58600
envelope_open = 62134
envelope_open_text = 63064
envelopes_bulk = 63092
equals = 61
eraser = 61741
ethernet = 63382
euro_sign = 61779
exclamation = 33
expand = 61541
explosion = 58601
eye = 61550
eye_dropper = 61947
eye_low_vision = 62120
eye_slash = 61552
f = 70
face_angry = 62806
face_dizzy = 62823
face_flushed = 62841
face_frown = 61721
face_frown_open = 62842
face_grimace = 62847
face_grin = 62848
face_grin_beam = 62850
face_grin_beam_sweat = 62851
face_grin_hearts = 62852
face_grin_squint = 62853
face_grin_squint_tears = 62854
face_grin_stars = 62855
face_grin_tears = 62856
face_grin_tongue = 62857
face_grin_tongue_squint = 62858
face_grin_tongue_wink = 62859
face_grin_wide = 62849
face_grin_wink = 62860
face_kiss = 62870
face_kiss_beam = 62871
face_kiss_wink_heart = 62872
face_laugh = 62873
face_laugh_beam = 62874
face_laugh_squint = 62875
face_laugh_wink = 62876
face_meh = 61722
face_meh_blank = 62884
face_rolling_eyes = 62885
face_sad_cry = 62899
face_sad_tear = 62900
face_smile = 61720
face_smile_beam = 62904
face_smile_wink = 62682
face_surprise = 62914
face_tired = 62920
fan = 63587
faucet = 57349
faucet_drip = 57350
fax = 61868
feather = 62765
feather_pointed = 62827
ferry = 58602
file = 61787
file_arrow_down = 62829
file_arrow_up = 62836
file_audio = 61895
file_circle_check = 58784
file_circle_exclamation = 58603
file_circle_minus = 58605
file_circle_plus = 58516
file_circle_question = 58607
file_circle_xmark = 58785
file_code = 61897
file_contract = 62828
file_csv = 63197
file_excel = 61891
file_export = 62830
file_fragment = 59031
file_half_dashed = 59032
file_image = 61893
file_import = 62831
file_invoice = 62832
file_invoice_dollar = 62833
file_lines = 61788
file_medical = 62583
file_pdf = 61889
file_pen = 62236
file_powerpoint = 61892
file_prescription = 62834
file_shield = 58608
file_signature = 62835
file_video = 61896
file_waveform = 62584
file_word = 61890
file_zipper = 61894
fill = 62837
fill_drip = 62838
film = 61448
filter = 61616
filter_circle_dollar = 63074
filter_circle_xmark = 57723
fingerprint = 62839
fire = 61549
fire_burner = 58609
fire_extinguisher = 61748
fire_flame_curved = 63460
fire_flame_simple = 62570
fish = 62840
fish_fins = 58610
flag = 61476
flag_checkered = 61726
flag_usa = 63309
flask = 61635
flask_vial = 58611
floppy_disk = 61639
florin_sign = 57732
folder = 61563
folder_closed = 57733
folder_minus = 63069
folder_open = 61564
folder_plus = 63070
folder_tree = 63490
font = 61489
font_awesome = 62132
football = 62542
forward = 61518
forward_fast = 61520
forward_step = 61521
franc_sign = 57743
frog = 62766
futbol = 61923
g = 71
gamepad = 61723
gas_pump = 62767
gauge = 63012
gauge_high = 63013
gauge_simple = 63017
gauge_simple_high = 63018
gavel = 61667
gear = 61459
gears = 61573
gem = 62373
genderless = 61997
ghost = 63202
gift = 61547
gifts = 63388
glass_water = 58612
glass_water_droplet = 58613
glasses = 62768
globe = 61612
golf_ball_tee = 62544
gopuram = 63076
graduation_cap = 61853
greater_than = 62
greater_than_equal = 62770
grip = 62861
grip_lines = 63396
grip_lines_vertical = 63397
grip_vertical = 62862
group_arrows_rotate = 58614
guarani_sign = 57754
guitar = 63398
gun = 57755
h = 72
hammer = 63203
hamsa = 63077
hand = 62038
hand_back_fist = 62037
hand_dots = 62561
hand_fist = 63198
hand_holding = 62653
hand_holding_dollar = 62656
hand_holding_droplet = 62657
hand_holding_hand = 58615
hand_holding_heart = 62654
hand_holding_medical = 57436
hand_lizard = 62040
hand_middle_finger = 63494
hand_peace = 62043
hand_point_down = 61607
hand_point_left = 61605
hand_point_right = 61604
hand_point_up = 61606
hand_pointer = 62042
hand_scissors = 62039
hand_sparkles = 57437
hand_spock = 62041
handcuffs = 58616
hands = 62119
hands_asl_interpreting = 62115
hands_bound = 58617
hands_bubbles = 57438
hands_clapping = 57768
hands_holding = 62658
hands_holding_child = 58618
hands_holding_circle = 58619
hands_praying = 63108
handshake = 62133
handshake_angle = 62660
handshake_simple = 62662
handshake_simple_slash = 57439
handshake_slash = 57440
hanukiah = 63206
hard_drive = 61600
hashtag = 35
hat_cowboy = 63680
hat_cowboy_side = 63681
hat_wizard = 63208
head_side_cough = 57441
head_side_cough_slash = 57442
head_side_mask = 57443
head_side_virus = 57444
heading = 61916
headphones = 61477
headphones_simple = 62863
headset = 62864
heart = 61444
heart_circle_bolt = 58620
heart_circle_check = 58621
heart_circle_exclamation = 58622
heart_circle_minus = 58623
heart_circle_plus = 58624
heart_circle_xmark = 58625
heart_crack = 63401
heart_pulse = 61982
helicopter = 62771
helicopter_symbol = 58626
helmet_safety = 63495
helmet_un = 58627
hexagon_nodes = 59033
hexagon_nodes_bolt = 59034
highlighter = 62865
hill_avalanche = 58631
hill_rockslide = 58632
hippo = 63213
hockey_puck = 62547
holly_berry = 63402
horse = 63216
horse_head = 63403
hospital = 61688
hospital_user = 63501
hot_tub_person = 62867
hotdog = 63503
hotel = 62868
hourglass = 62036
hourglass_end = 62035
hourglass_half = 62034
hourglass_start = 62033
house = 61461
house_chimney = 58287
house_chimney_crack = 63217
house_chimney_medical = 63474
house_chimney_user = 57445
house_chimney_window = 57357
house_circle_check = 58633
house_circle_exclamation = 58634
house_circle_xmark = 58635
house_crack = 58289
house_fire = 58636
house_flag = 58637
house_flood_water = 58638
house_flood_water_circle_arrow_right = 58639
house_laptop = 57446
house_lock = 58640
house_medical = 58290
house_medical_circle_check = 58641
house_medical_circle_exclamation = 58642
house_medical_circle_xmark = 58643
house_medical_flag = 58644
house_signal = 57362
house_tsunami = 58645
house_user = 57776
hryvnia_sign = 63218
hurricane = 63313
i = 73
i_cursor = 62022
ice_cream = 63504
icicles = 63405
icons = 63597
id_badge = 62145
id_card = 62146
id_card_clip = 62591
igloo = 63406
image = 61502
image_portrait = 62432
images = 62210
inbox = 61468
indent = 61500
indian_rupee_sign = 57788
industry = 62069
infinity = 62772
info = 61737
italic = 61491
j = 74
jar = 58646
jar_wheat = 58647
jedi = 63081
jet_fighter = 61691
jet_fighter_up = 58648
joint = 62869
jug_detergent = 58649
k = 75
kaaba = 63083
key = 61572
keyboard = 61724
khanda = 63085
kip_sign = 57796
kit_medical = 62585
kitchen_set = 58650
kiwi_bird = 62773
L = 76
land_mine_on = 58651
landmark = 63087
landmark_dome = 63314
landmark_flag = 58652
language = 61867
laptop = 61705
laptop_code = 62972
laptop_file = 58653
laptop_medical = 63506
lari_sign = 57800
layer_group = 62973
leaf = 61548
left_long = 62218
left_right = 62263
lemon = 61588
less_than = 60
less_than_equal = 62775
life_ring = 61901
lightbulb = 61675
lines_leaning = 58654
link = 61633
link_slash = 61735
lira_sign = 61845
list = 61498
list_check = 61614
list_ol = 61643
list_ul = 61642
litecoin_sign = 57811
location_arrow = 61732
location_crosshairs = 62977
location_dot = 62405
location_pin = 61505
location_pin_lock = 58655
lock = 61475
lock_open = 62401
locust = 58656
lungs = 62980
lungs_virus = 57447
m = 77
magnet = 61558
magnifying_glass = 61442
magnifying_glass_arrow_right = 58657
magnifying_glass_chart = 58658
magnifying_glass_dollar = 63112
magnifying_glass_location = 63113
magnifying_glass_minus = 61456
magnifying_glass_plus = 61454
manat_sign = 57813
map = 62073
map_location = 62879
map_location_dot = 62880
map_pin = 62070
marker = 62881
mars = 61986
mars_and_venus = 61988
mars_and_venus_burst = 58659
mars_double = 61991
mars_stroke = 61993
mars_stroke_right = 61995
mars_stroke_up = 61994
martini_glass = 62843
martini_glass_citrus = 62817
martini_glass_empty = 61440
mask = 63226
mask_face = 57815
mask_ventilator = 58660
masks_theater = 63024
mattress_pillow = 58661
maximize = 62238
medal = 62882
memory = 62776
menorah = 63094
mercury = 61987
message = 62074
meteor = 63315
microchip = 62171
microphone = 61744
microphone_lines = 62409
microphone_lines_slash = 62777
microphone_slash = 61745
microscope = 62992
mill_sign = 57837
minimize = 63372
minus = 61544
mitten = 63413
mobile = 62414
mobile_button = 61707
mobile_retro = 58663
mobile_screen = 62415
mobile_screen_button = 62413
money_bill = 61654
money_bill_1 = 62417
money_bill_1_wave = 62779
money_bill_transfer = 58664
money_bill_trend_up = 58665
money_bill_wave = 62778
money_bill_wheat = 58666
money_bills = 57843
money_check = 62780
money_check_dollar = 62781
monument = 62886
moon = 61830
mortar_pestle = 62887
mosque = 63096
mosquito = 58667
mosquito_net = 58668
motorcycle = 61980
mound = 58669
mountain = 63228
mountain_city = 58670
mountain_sun = 58671
mug_hot = 63414
mug_saucer = 61684
music = 61441
n = 78
naira_sign = 57846
network_wired = 63231
neuter = 61996
newspaper = 61930
not_equal = 62782
notdef = 57854
note_sticky = 62025
notes_medical = 62593
o = 79
object_group = 62023
object_ungroup = 62024
oil_can = 62995
oil_well = 58674
om = 63097
otter = 63232
outdent = 61499
p = 80
pager = 63509
paint_roller = 62890
paintbrush = 61948
palette = 62783
pallet = 62594
panorama = 57865
paper_plane = 61912
paperclip = 61638
parachute_box = 62669
paragraph = 61917
passport = 62891
paste = 61674
pause = 61516
paw = 61872
peace = 63100
pen = 62212
pen_clip = 62213
pen_fancy = 62892
pen_nib = 62893
pen_ruler = 62894
pen_to_square = 61508
pencil = 62211
people_arrows = 57448
people_carry_box = 62670
people_group = 58675
people_line = 58676
people_pulling = 58677
people_robbery = 58678
people_roof = 58679
pepper_hot = 63510
percent = 37
person = 61827
person_arrow_down_to_line = 58680
person_arrow_up_from_line = 58681
person_biking = 63562
person_booth = 63318
person_breastfeeding = 58682
person_burst = 58683
person_cane = 58684
person_chalkboard = 58685
person_circle_check = 58686
person_circle_exclamation = 58687
person_circle_minus = 58688
person_circle_plus = 58689
person_circle_question = 58690
person_circle_xmark = 58691
person_digging = 63582
person_dots_from_line = 62576
person_dress = 61826
person_dress_burst = 58692
person_drowning = 58693
person_falling = 58694
person_falling_burst = 58695
person_half_dress = 58696
person_harassing = 58697
person_hiking = 63212
person_military_pointing = 58698
person_military_rifle = 58699
person_military_to_person = 58700
person_praying = 63107
person_pregnant = 58142
person_rays = 58701
person_rifle = 58702
person_running = 63244
person_shelter = 58703
person_skating = 63429
person_skiing = 63433
person_skiing_nordic = 63434
person_snowboarding = 63438
person_swimming = 62916
person_through_window = 58793
person_walking = 62804
person_walking_arrow_loop_left = 58705
person_walking_arrow_right = 58706
person_walking_dashed_line_arrow_right = 58707
person_walking_luggage = 58708
person_walking_with_cane = 62109
peseta_sign = 57889
peso_sign = 57890
phone = 61589
phone_flip = 63609
phone_slash = 62429
phone_volume = 62112
photo_film = 63612
piggy_bank = 62675
pills = 62596
pizza_slice = 63512
place_of_worship = 63103
plane = 61554
plane_arrival = 62895
plane_circle_check = 58709
plane_circle_exclamation = 58710
plane_circle_xmark = 58711
plane_departure = 62896
plane_lock = 58712
plane_slash = 57449
plane_up = 57901
plant_wilt = 58794
plate_wheat = 58714
play = 61515
plug = 61926
plug_circle_bolt = 58715
plug_circle_check = 58716
plug_circle_exclamation = 58717
plug_circle_minus = 58718
plug_circle_plus = 58719
plug_circle_xmark = 58720
plus = 43
plus_minus = 58428
podcast = 62158
poo = 62206
poo_storm = 63322
poop = 63001
power_off = 61457
prescription = 62897
prescription_bottle = 62597
prescription_bottle_medical = 62598
print = 61487
pump_medical = 57450
pump_soap = 57451
puzzle_piece = 61742
q = 81
qrcode = 61481
question = 63
quote_left = 61709
quote_right = 61710
r = 82
radiation = 63417
radio = 63703
rainbow = 63323
ranking_star = 58721
receipt = 62787
record_vinyl = 63705
rectangle_ad = 63041
rectangle_list = 61474
rectangle_xmark = 62480
recycle = 61880
registered = 62045
repeat = 62307
reply = 62437
reply_all = 61730
republican = 63326
restroom = 63421
retweet = 61561
ribbon = 62678
right_from_bracket = 62197
right_left = 62306
right_long = 62219
right_to_bracket = 62198
ring = 63243
road = 61464
road_barrier = 58722
road_bridge = 58723
road_circle_check = 58724
road_circle_exclamation = 58725
road_circle_xmark = 58726
road_lock = 58727
road_spikes = 58728
robot = 62788
rocket = 61749
rotate = 62193
rotate_left = 62186
rotate_right = 62201
route = 62679
rss = 61598
ruble_sign = 61784
rug = 58729
ruler = 62789
ruler_combined = 62790
ruler_horizontal = 62791
ruler_vertical = 62792
rupee_sign = 61782
rupiah_sign = 57917
s = 83
sack_dollar = 63517
sack_xmark = 58730
sailboat = 58437
satellite = 63423
satellite_dish = 63424
scale_balanced = 62030
scale_unbalanced = 62741
scale_unbalanced_flip = 62742
school = 62793
school_circle_check = 58731
school_circle_exclamation = 58732
school_circle_xmark = 58733
school_flag = 58734
school_lock = 58735
scissors = 61636
screwdriver = 62794
screwdriver_wrench = 63449
scroll = 63246
scroll_torah = 63136
sd_card = 63426
section = 58439
seedling = 62680
server = 62003
shapes = 63007
share = 61540
share_from_square = 61773
share_nodes = 61920
sheet_plastic = 58737
shekel_sign = 61963
shield = 61746
shield_cat = 58738
shield_dog = 58739
shield_halved = 62445
shield_heart = 58740
shield_virus = 57452
ship = 61978
shirt = 62803
shoe_prints = 62795
shop = 62799
shop_lock = 58533
shop_slash = 57456
shower = 62156
shrimp = 58440
shuffle = 61556
shuttle_space = 61847
sign_hanging = 62681
signal = 61458
signature = 62903
signs_post = 62071
sim_card = 63428
sink = 57453
sitemap = 61672
skull = 62796
skull_crossbones = 63252
slash = 63253
sleigh = 63436
sliders = 61918
smog = 63327
smoking = 62605
snowflake = 62172
snowman = 63440
snowplow = 63442
soap = 57454
socks = 63126
solar_panel = 62906
sort = 61660
sort_down = 61661
sort_up = 61662
spa = 62907
spaghetti_monster_flying = 63099
spell_check = 63633
spider = 63255
spinner = 61712
splotch = 62908
spoon = 62181
spray_can = 62909
spray_can_sparkles = 62928
square = 61640
square_arrow_up_right = 61772
square_binary = 59035
square_caret_down = 61776
square_caret_left = 61841
square_caret_right = 61778
square_caret_up = 61777
square_check = 61770
square_envelope = 61849
square_full = 62556
square_h = 61693
square_minus = 61766
square_nfi = 58742
square_parking = 62784
square_pen = 61771
square_person_confined = 58743
square_phone = 61592
square_phone_flip = 63611
square_plus = 61694
square_poll_horizontal = 63106
square_poll_vertical = 63105
square_root_variable = 63128
square_rss = 61763
square_share_nodes = 61921
square_up_right = 62304
square_virus = 58744
square_xmark = 62163
staff_snake = 58745
stairs = 57993
stamp = 62911
stapler = 58799
star = 61445
star_and_crescent = 63129
star_half = 61577
star_half_stroke = 62912
star_of_david = 63130
star_of_life = 63009
sterling_sign = 61780
stethoscope = 61681
stop = 61517
stopwatch = 62194
stopwatch_20 = 57455
store = 62798
store_slash = 57457
street_view = 61981
strikethrough = 61644
stroopwafel = 62801
subscript = 61740
suitcase = 61682
suitcase_medical = 61690
suitcase_rolling = 62913
sun = 61829
sun_plant_wilt = 58746
superscript = 61739
swatchbook = 62915
synagogue = 63131
syringe = 62606
t = 84
table = 61646
table_cells = 61450
table_cells_column_lock = 59000
table_cells_large = 61449
table_cells_row_lock = 59002
table_cells_row_unlock = 59025
table_columns = 61659
table_list = 61451
table_tennis_paddle_ball = 62557
tablet = 62459
tablet_button = 61706
tablet_screen_button = 62458
tablets = 62608
tachograph_digital = 62822
tag = 61483
tags = 61484
tape = 62683
tarp = 58747
tarp_droplet = 58748
taxi = 61882
teeth = 63022
teeth_open = 63023
temperature_arrow_down = 57407
temperature_arrow_up = 57408
temperature_empty = 62155
temperature_full = 62151
temperature_half = 62153
temperature_high = 63337
temperature_low = 63339
temperature_quarter = 62154
temperature_three_quarters = 62152
tenge_sign = 63447
tent = 58749
tent_arrow_down_to_line = 58750
tent_arrow_left_right = 58751
tent_arrow_turn_left = 58752
tent_arrows_down = 58753
tents = 58754
terminal = 61728
text_height = 61492
text_slash = 63613
text_width = 61493
thermometer = 62609
thumbs_down = 61797
thumbs_up = 61796
thumbtack = 61581
thumbtack_slash = 59023
ticket = 61765
ticket_simple = 62463
timeline = 58012
toggle_off = 61956
toggle_on = 61957
toilet = 63448
toilet_paper = 63262
toilet_paper_slash = 57458
toilet_portable = 58755
toilets_portable = 58756
toolbox = 62802
tooth = 62921
torii_gate = 63137
tornado = 63343
tower_broadcast = 62745
tower_cell = 58757
tower_observation = 58758
tractor = 63266
trademark = 62044
traffic_light = 63031
trailer = 57409
train = 62008
train_subway = 62009
train_tram = 58804
transgender = 61989
trash = 61944
trash_arrow_up = 63529
trash_can = 62189
trash_can_arrow_up = 63530
tree = 61883
tree_city = 58759
triangle_exclamation = 61553
trophy = 61585
trowel = 58761
trowel_bricks = 58762
truck = 61649
truck_arrow_right = 58763
truck_droplet = 58764
truck_fast = 62603
truck_field = 58765
truck_field_un = 58766
truck_front = 58039
truck_medical = 61689
truck_monster = 63035
truck_moving = 62687
truck_pickup = 63036
truck_plane = 58767
truck_ramp_box = 62686
tty = 61924
turkish_lira_sign = 58043
turn_down = 62398
turn_up = 62399
tv = 62060
u = 85
umbrella = 61673
umbrella_beach = 62922
underline = 61645
universal_access = 62106
unlock = 61596
unlock_keyhole = 61758
up_down = 62264
up_down_left_right = 61618
up_long = 62220
up_right_and_down_left_from_center = 62500
up_right_from_square = 62301
upload = 61587
user = 61447
user_astronaut = 62715
user_check = 62716
user_clock = 62717
user_doctor = 61680
user_gear = 62718
user_graduate = 62721
user_group = 62720
user_injured = 63272
user_large = 62470
user_large_slash = 62714
user_lock = 62722
user_minus = 62723
user_ninja = 62724
user_nurse = 63535
user_pen = 62719
user_plus = 62004
user_secret = 61979
user_shield = 62725
user_slash = 62726
user_tag = 62727
user_tie = 62728
user_xmark = 62005
users = 61632
users_between_lines = 58769
users_gear = 62729
users_line = 58770
users_rays = 58771
users_rectangle = 58772
users_slash = 57459
users_viewfinder = 58773
utensils = 62183
v = 86
van_shuttle = 62902
vault = 58053
vector_square = 62923
venus = 61985
venus_double = 61990
venus_mars = 61992
vest = 57477
vest_patches = 57478
vial = 62610
vial_circle_check = 58774
vial_virus = 58775
vials = 62611
video = 61501
video_slash = 62690
vihara = 63143
virus = 57460
virus_covid = 58536
virus_covid_slash = 58537
virus_slash = 57461
viruses = 57462
voicemail = 63639
volcano = 63344
volleyball = 62559
volume_high = 61480
volume_low = 61479
volume_off = 61478
volume_xmark = 63145
vr_cardboard = 63273
w = 87
walkie_talkie = 63727
wallet = 62805
wand_magic = 61648
wand_magic_sparkles = 58058
wand_sparkles = 63275
warehouse = 62612
water = 63347
water_ladder = 62917
wave_square = 63550
web_awesome = 59010
weight_hanging = 62925
weight_scale = 62614
wheat_awn = 58061
wheat_awn_circle_exclamation = 58776
wheelchair = 61843
wheelchair_move = 58062
whiskey_glass = 63392
wifi = 61931
wind = 63278
window_maximize = 62160
window_minimize = 62161
window_restore = 62162
wine_bottle = 63279
wine_glass = 62691
wine_glass_empty = 62926
won_sign = 61785
worm = 58777
wrench = 61613
x = 88
x_ray = 62615
xmark = 61453
xmarks_lines = 58778
y = 89
yen_sign = 61783
yin_yang = 63149
z = 90



from __future__ import annotations
from typing import TypeVar, Generic

from ...logging import log_func_call
from ..widgets import GuiWindowLikeView, GuiWindowLike, GuiWindowLikeParentType
from ..qt import QDialog


GuiDialogPresType = TypeVar('GuiDialogPresType', bound='GuiDialog')
GuiDialogViewType = TypeVar('GuiDialogViewType', bound='GuiDialogView')


class GuiDialog(GuiWindowLike[GuiDialogViewType], Generic[GuiDialogViewType]):
    @log_func_call
    def __init__(self, basetitle: str,
                 gui_parent: GuiWindowLikeParentType | None = None,
                 *view_args, **view_kwargs):
        super().__init__(basetitle, gui_parent, *view_args, **view_kwargs)


class GuiDialogView(GuiWindowLikeView[GuiDialogPresType, QDialog],
                    Generic[GuiDialogPresType]):
    @log_func_call
    def create_qtobj(self, *args, **kwargs):
        return QDialog(*args, **kwargs)



# from __future__ import annotations
from typing import TYPE_CHECKING

from ....logging import log_func_call, DEBUGLOW2
from ....app import PyRandyOSApp
from ...qt import (
    QVBoxLayout, QTreeView, QDialogButtonBox, QAbstractItemView,
    QStandardItemModel, QStandardItem, QSize, QHBoxLayout,
)
from ...utils import create_icon_button
from .. import GuiDialogView
from .icons import SaveLocalConfigIcon, SaveConfigIcon

if TYPE_CHECKING:
    from .pres import ConfigTreeDialog


class ConfigTreeDialogView(GuiDialogView['ConfigTreeDialog']):
    @log_func_call
    def __init__(self, basetitle: str, presenter: 'ConfigTreeDialog' = None,
                 *qtobj_args, **qtobj_kwargs):
        GuiDialogView.__init__(self, basetitle, presenter, *qtobj_args,
                               **qtobj_kwargs)
        qtobj = self.qtobj
        qtobj.resize(*PyRandyOSApp.get_default_win_size())
        self.layout = QVBoxLayout(qtobj)
        self.create_tree()

    @log_func_call
    def create_tree(self):
        qtobj = self.qtobj
        layout = self.layout
        pres: 'ConfigTreeDialog' = self.gui_pres

        itemmodel = QStandardItemModel()
        itemmodel.setHorizontalHeaderLabels(["Key", "Value"])
        self.itemmodel = itemmodel

        tree = QTreeView(qtobj)
        tree.setEditTriggers(QAbstractItemView.NoEditTriggers)
        tree.setModel(itemmodel)
        layout.addWidget(tree)
        self.tree = tree

        header = tree.header()
        header.setStretchLastSection(True)

        hbox = QHBoxLayout()
        layout.addLayout(hbox)

        savelocalbtn = create_icon_button(qtobj, QSize(32, 32),
                                          SaveLocalConfigIcon.icon(),
                                          pres.click_save_local_config,
                                          "Save Local Config")
        hbox.addWidget(savelocalbtn)
        self.savelocalbtn = savelocalbtn

        savecfgbtn = create_icon_button(qtobj, QSize(32, 32),
                                        SaveConfigIcon.icon(),
                                        pres.click_save_config,
                                        "Export Full Config")
        hbox.addWidget(savecfgbtn)
        self.savecfgbtn = savecfgbtn

        dlgbuttons = QDialogButtonBox(QDialogButtonBox.Ok, qtobj)
        dlgbuttons.accepted.connect(qtobj.accept)
        hbox.addStretch()
        hbox.addWidget(dlgbuttons)
        self.dlgbuttons = dlgbuttons

        self.populate_tree(itemmodel, pres.get_config())
        tree.expandAll()
        tree.resizeColumnToContents(0)

    @log_func_call(DEBUGLOW2)
    def populate_tree(self, parent_item: QStandardItemModel | QStandardItem,
                      value: dict | list):
        pairs = (sorted(value.items(), key=lambda x: x[0])
                 if isinstance(value, dict)
                 else enumerate(value) if isinstance(value, list)
                 else ())
        for k, v in pairs:
            key_item = QStandardItem(f"[{k}]" if isinstance(value, list)
                                     else str(k))
            key_item.setEditable(False)

            value_item = QStandardItem("" if isinstance(v, (dict, list))
                                       else str(v))
            value_item.setEditable(False)

            parent_item.appendRow([key_item, value_item])
            self.populate_tree(key_item, v)



'''
# PyRandyOS

Library of common functions for Python applications

[![GitHub Badge](https://img.shields.io/badge/GitHub-181717?logo=github&logoColor=fff&style=plastic)](https://github.com/emanspeaks/pyrandyos)
[![CI Status](https://github.com/emanspeaks/pyrandyos/actions/workflows/ci.yml/badge.svg)](https://github.com/emanspeaks/pyrandyos/actions)
[![last-commit](https://img.shields.io/github/last-commit/emanspeaks/pyrandyos)](https://github.com/emanspeaks/pyrandyos/commits/main)
[![PyPI Downloads](https://img.shields.io/pypi/dm/pyrandyos?label=PyPI%20downloads)](https://pypi.org/project/pyrandyos/)
<!-- [![Conda Downloads](https://img.shields.io/conda/dn/conda-forge/pyrandyos?label=Conda%20downloads)](https://anaconda.org/conda-forge/pyrandyos) -->

This library was created to assist with rapid prototyping of Qt GUIs and other
common functionality Randy needs on a day-to-day basis.
'''  # noqa: E501

from .version import __version__  # noqa: F401
from .app import PyRandyOSApp  # noqa: F401



# This file is auto-generated by pyrandyos/gui/icons/update_from_spec.py  # noqa: E501
# Do not edit.
_24_hours_fill = 59905
_24_hours_line = 59906
_4k_fill = 59907
_4k_line = 59908
a_b = 59909
account_box_fill = 59910
account_box_line = 59911
account_circle_fill = 59912
account_circle_line = 59913
account_pin_box_fill = 59914
account_pin_box_line = 59915
account_pin_circle_fill = 59916
account_pin_circle_line = 59917
add_box_fill = 59918
add_box_line = 59919
add_circle_fill = 59920
add_circle_line = 59921
add_fill = 59922
add_line = 59923
admin_fill = 59924
admin_line = 59925
advertisement_fill = 59926
advertisement_line = 59927
airplay_fill = 59928
airplay_line = 59929
alarm_fill = 59930
alarm_line = 59931
alarm_warning_fill = 59932
alarm_warning_line = 59933
album_fill = 59934
album_line = 59935
alert_fill = 59936
alert_line = 59937
aliens_fill = 59938
aliens_line = 59939
align_bottom = 59940
align_center = 59941
align_justify = 59942
align_left = 59943
align_right = 59944
align_top = 59945
align_vertically = 59946
alipay_fill = 59947
alipay_line = 59948
amazon_fill = 59949
amazon_line = 59950
anchor_fill = 59951
anchor_line = 59952
ancient_gate_fill = 59953
ancient_gate_line = 59954
ancient_pavilion_fill = 59955
ancient_pavilion_line = 59956
android_fill = 59957
android_line = 59958
angularjs_fill = 59959
angularjs_line = 59960
anticlockwise_2_fill = 59961
anticlockwise_2_line = 59962
anticlockwise_fill = 59963
anticlockwise_line = 59964
app_store_fill = 59965
app_store_line = 59966
apple_fill = 59967
apple_line = 59968
apps_2_fill = 59969
apps_2_line = 59970
apps_fill = 59971
apps_line = 59972
archive_drawer_fill = 59973
archive_drawer_line = 59974
archive_fill = 59975
archive_line = 59976
arrow_down_circle_fill = 59977
arrow_down_circle_line = 59978
arrow_down_fill = 59979
arrow_down_line = 59980
arrow_down_s_fill = 59981
arrow_down_s_line = 59982
arrow_drop_down_fill = 59983
arrow_drop_down_line = 59984
arrow_drop_left_fill = 59985
arrow_drop_left_line = 59986
arrow_drop_right_fill = 59987
arrow_drop_right_line = 59988
arrow_drop_up_fill = 59989
arrow_drop_up_line = 59990
arrow_go_back_fill = 59991
arrow_go_back_line = 59992
arrow_go_forward_fill = 59993
arrow_go_forward_line = 59994
arrow_left_circle_fill = 59995
arrow_left_circle_line = 59996
arrow_left_down_fill = 59997
arrow_left_down_line = 59998
arrow_left_fill = 59999
arrow_left_line = 60000
arrow_left_right_fill = 60001
arrow_left_right_line = 60002
arrow_left_s_fill = 60003
arrow_left_s_line = 60004
arrow_left_up_fill = 60005
arrow_left_up_line = 60006
arrow_right_circle_fill = 60007
arrow_right_circle_line = 60008
arrow_right_down_fill = 60009
arrow_right_down_line = 60010
arrow_right_fill = 60011
arrow_right_line = 60012
arrow_right_s_fill = 60013
arrow_right_s_line = 60014
arrow_right_up_fill = 60015
arrow_right_up_line = 60016
arrow_up_circle_fill = 60017
arrow_up_circle_line = 60018
arrow_up_down_fill = 60019
arrow_up_down_line = 60020
arrow_up_fill = 60021
arrow_up_line = 60022
arrow_up_s_fill = 60023
arrow_up_s_line = 60024
artboard_2_fill = 60025
artboard_2_line = 60026
artboard_fill = 60027
artboard_line = 60028
article_fill = 60029
article_line = 60030
aspect_ratio_fill = 60031
aspect_ratio_line = 60032
asterisk = 60033
at_fill = 60034
at_line = 60035
attachment_2 = 60036
attachment_fill = 60037
attachment_line = 60038
auction_fill = 60039
auction_line = 60040
award_fill = 60041
award_line = 60042
baidu_fill = 60043
baidu_line = 60044
ball_pen_fill = 60045
ball_pen_line = 60046
bank_card_2_fill = 60047
bank_card_2_line = 60048
bank_card_fill = 60049
bank_card_line = 60050
bank_fill = 60051
bank_line = 60052
bar_chart_2_fill = 60053
bar_chart_2_line = 60054
bar_chart_box_fill = 60055
bar_chart_box_line = 60056
bar_chart_fill = 60057
bar_chart_grouped_fill = 60058
bar_chart_grouped_line = 60059
bar_chart_horizontal_fill = 60060
bar_chart_horizontal_line = 60061
bar_chart_line = 60062
barcode_box_fill = 60063
barcode_box_line = 60064
barcode_fill = 60065
barcode_line = 60066
barricade_fill = 60067
barricade_line = 60068
base_station_fill = 60069
base_station_line = 60070
basketball_fill = 60071
basketball_line = 60072
battery_2_charge_fill = 60073
battery_2_charge_line = 60074
battery_2_fill = 60075
battery_2_line = 60076
battery_charge_fill = 60077
battery_charge_line = 60078
battery_fill = 60079
battery_line = 60080
battery_low_fill = 60081
battery_low_line = 60082
battery_saver_fill = 60083
battery_saver_line = 60084
battery_share_fill = 60085
battery_share_line = 60086
bear_smile_fill = 60087
bear_smile_line = 60088
behance_fill = 60089
behance_line = 60090
bell_fill = 60091
bell_line = 60092
bike_fill = 60093
bike_line = 60094
bilibili_fill = 60095
bilibili_line = 60096
bill_fill = 60097
bill_line = 60098
billiards_fill = 60099
billiards_line = 60100
bit_coin_fill = 60101
bit_coin_line = 60102
blaze_fill = 60103
blaze_line = 60104
bluetooth_connect_fill = 60105
bluetooth_connect_line = 60106
bluetooth_fill = 60107
bluetooth_line = 60108
blur_off_fill = 60109
blur_off_line = 60110
body_scan_fill = 60111
body_scan_line = 60112
bold = 60113
book_2_fill = 60114
book_2_line = 60115
book_3_fill = 60116
book_3_line = 60117
book_fill = 60118
book_line = 60119
book_mark_fill = 60120
book_mark_line = 60121
book_open_fill = 60122
book_open_line = 60123
book_read_fill = 60124
book_read_line = 60125
booklet_fill = 60126
booklet_line = 60127
bookmark_2_fill = 60128
bookmark_2_line = 60129
bookmark_3_fill = 60130
bookmark_3_line = 60131
bookmark_fill = 60132
bookmark_line = 60133
boxing_fill = 60134
boxing_line = 60135
braces_fill = 60136
braces_line = 60137
brackets_fill = 60138
brackets_line = 60139
briefcase_2_fill = 60140
briefcase_2_line = 60141
briefcase_3_fill = 60142
briefcase_3_line = 60143
briefcase_4_fill = 60144
briefcase_4_line = 60145
briefcase_5_fill = 60146
briefcase_5_line = 60147
briefcase_fill = 60148
briefcase_line = 60149
bring_forward = 60150
bring_to_front = 60151
broadcast_fill = 60152
broadcast_line = 60153
brush_2_fill = 60154
brush_2_line = 60155
brush_3_fill = 60156
brush_3_line = 60157
brush_4_fill = 60158
brush_4_line = 60159
brush_fill = 60160
brush_line = 60161
bubble_chart_fill = 60162
bubble_chart_line = 60163
bug_2_fill = 60164
bug_2_line = 60165
bug_fill = 60166
bug_line = 60167
building_2_fill = 60168
building_2_line = 60169
building_3_fill = 60170
building_3_line = 60171
building_4_fill = 60172
building_4_line = 60173
building_fill = 60174
building_line = 60175
bus_2_fill = 60176
bus_2_line = 60177
bus_fill = 60178
bus_line = 60179
bus_wifi_fill = 60180
bus_wifi_line = 60181
cactus_fill = 60182
cactus_line = 60183
cake_2_fill = 60184
cake_2_line = 60185
cake_3_fill = 60186
cake_3_line = 60187
cake_fill = 60188
cake_line = 60189
calculator_fill = 60190
calculator_line = 60191
calendar_2_fill = 60192
calendar_2_line = 60193
calendar_check_fill = 60194
calendar_check_line = 60195
calendar_event_fill = 60196
calendar_event_line = 60197
calendar_fill = 60198
calendar_line = 60199
calendar_todo_fill = 60200
calendar_todo_line = 60201
camera_2_fill = 60202
camera_2_line = 60203
camera_3_fill = 60204
camera_3_line = 60205
camera_fill = 60206
camera_lens_fill = 60207
camera_lens_line = 60208
camera_line = 60209
camera_off_fill = 60210
camera_off_line = 60211
camera_switch_fill = 60212
camera_switch_line = 60213
capsule_fill = 60214
capsule_line = 60215
car_fill = 60216
car_line = 60217
car_washing_fill = 60218
car_washing_line = 60219
caravan_fill = 60220
caravan_line = 60221
cast_fill = 60222
cast_line = 60223
cellphone_fill = 60224
cellphone_line = 60225
celsius_fill = 60226
celsius_line = 60227
centos_fill = 60228
centos_line = 60229
character_recognition_fill = 60230
character_recognition_line = 60231
charging_pile_2_fill = 60232
charging_pile_2_line = 60233
charging_pile_fill = 60234
charging_pile_line = 60235
chat_1_fill = 60236
chat_1_line = 60237
chat_2_fill = 60238
chat_2_line = 60239
chat_3_fill = 60240
chat_3_line = 60241
chat_4_fill = 60242
chat_4_line = 60243
chat_check_fill = 60244
chat_check_line = 60245
chat_delete_fill = 60246
chat_delete_line = 60247
chat_download_fill = 60248
chat_download_line = 60249
chat_follow_up_fill = 60250
chat_follow_up_line = 60251
chat_forward_fill = 60252
chat_forward_line = 60253
chat_heart_fill = 60254
chat_heart_line = 60255
chat_history_fill = 60256
chat_history_line = 60257
chat_new_fill = 60258
chat_new_line = 60259
chat_off_fill = 60260
chat_off_line = 60261
chat_poll_fill = 60262
chat_poll_line = 60263
chat_private_fill = 60264
chat_private_line = 60265
chat_quote_fill = 60266
chat_quote_line = 60267
chat_settings_fill = 60268
chat_settings_line = 60269
chat_smile_2_fill = 60270
chat_smile_2_line = 60271
chat_smile_3_fill = 60272
chat_smile_3_line = 60273
chat_smile_fill = 60274
chat_smile_line = 60275
chat_upload_fill = 60276
chat_upload_line = 60277
chat_voice_fill = 60278
chat_voice_line = 60279
check_double_fill = 60280
check_double_line = 60281
check_fill = 60282
check_line = 60283
checkbox_blank_circle_fill = 60284
checkbox_blank_circle_line = 60285
checkbox_blank_fill = 60286
checkbox_blank_line = 60287
checkbox_circle_fill = 60288
checkbox_circle_line = 60289
checkbox_fill = 60290
checkbox_indeterminate_fill = 60291
checkbox_indeterminate_line = 60292
checkbox_line = 60293
checkbox_multiple_blank_fill = 60294
checkbox_multiple_blank_line = 60295
checkbox_multiple_fill = 60296
checkbox_multiple_line = 60297
china_railway_fill = 60298
china_railway_line = 60299
chrome_fill = 60300
chrome_line = 60301
clapperboard_fill = 60302
clapperboard_line = 60303
clipboard_fill = 60304
clipboard_line = 60305
clockwise_2_fill = 60306
clockwise_2_line = 60307
clockwise_fill = 60308
clockwise_line = 60309
close_circle_fill = 60310
close_circle_line = 60311
close_fill = 60312
close_line = 60313
closed_captioning_fill = 60314
closed_captioning_line = 60315
cloud_fill = 60316
cloud_line = 60317
cloud_off_fill = 60318
cloud_off_line = 60319
cloud_windy_fill = 60320
cloud_windy_line = 60321
cloudy_2_fill = 60322
cloudy_2_line = 60323
cloudy_fill = 60324
cloudy_line = 60325
code_box_fill = 60326
code_box_line = 60327
code_fill = 60328
code_line = 60329
code_s_fill = 60330
code_s_line = 60331
code_s_slash_fill = 60332
code_s_slash_line = 60333
code_view = 60334
codepen_fill = 60335
codepen_line = 60336
coin_fill = 60337
coin_line = 60338
coins_fill = 60339
coins_line = 60340
collage_fill = 60341
collage_line = 60342
command_fill = 60343
command_line = 60344
community_fill = 60345
community_line = 60346
compass_2_fill = 60347
compass_2_line = 60348
compass_3_fill = 60349
compass_3_line = 60350
compass_4_fill = 60351
compass_4_line = 60352
compass_discover_fill = 60353
compass_discover_line = 60354
compass_fill = 60355
compass_line = 60356
compasses_2_fill = 60357
compasses_2_line = 60358
compasses_fill = 60359
compasses_line = 60360
computer_fill = 60361
computer_line = 60362
contacts_book_2_fill = 60363
contacts_book_2_line = 60364
contacts_book_fill = 60365
contacts_book_line = 60366
contacts_book_upload_fill = 60367
contacts_book_upload_line = 60368
contacts_fill = 60369
contacts_line = 60370
contrast_2_fill = 60371
contrast_2_line = 60372
contrast_drop_2_fill = 60373
contrast_drop_2_line = 60374
contrast_drop_fill = 60375
contrast_drop_line = 60376
contrast_fill = 60377
contrast_line = 60378
copper_coin_fill = 60379
copper_coin_line = 60380
copper_diamond_fill = 60381
copper_diamond_line = 60382
copyleft_fill = 60383
copyleft_line = 60384
copyright_fill = 60385
copyright_line = 60386
coreos_fill = 60387
coreos_line = 60388
coupon_2_fill = 60389
coupon_2_line = 60390
coupon_3_fill = 60391
coupon_3_line = 60392
coupon_4_fill = 60393
coupon_4_line = 60394
coupon_5_fill = 60395
coupon_5_line = 60396
coupon_fill = 60397
coupon_line = 60398
cpu_fill = 60399
cpu_line = 60400
creative_commons_by_fill = 60401
creative_commons_by_line = 60402
creative_commons_fill = 60403
creative_commons_line = 60404
creative_commons_nc_fill = 60405
creative_commons_nc_line = 60406
creative_commons_nd_fill = 60407
creative_commons_nd_line = 60408
creative_commons_sa_fill = 60409
creative_commons_sa_line = 60410
creative_commons_zero_fill = 60411
creative_commons_zero_line = 60412
criminal_fill = 60413
criminal_line = 60414
crop_2_fill = 60415
crop_2_line = 60416
crop_fill = 60417
crop_line = 60418
css3_fill = 60419
css3_line = 60420
cup_fill = 60421
cup_line = 60422
currency_fill = 60423
currency_line = 60424
cursor_fill = 60425
cursor_line = 60426
customer_service_2_fill = 60427
customer_service_2_line = 60428
customer_service_fill = 60429
customer_service_line = 60430
dashboard_2_fill = 60431
dashboard_2_line = 60432
dashboard_3_fill = 60433
dashboard_3_line = 60434
dashboard_fill = 60435
dashboard_line = 60436
database_2_fill = 60437
database_2_line = 60438
database_fill = 60439
database_line = 60440
delete_back_2_fill = 60441
delete_back_2_line = 60442
delete_back_fill = 60443
delete_back_line = 60444
delete_bin_2_fill = 60445
delete_bin_2_line = 60446
delete_bin_3_fill = 60447
delete_bin_3_line = 60448
delete_bin_4_fill = 60449
delete_bin_4_line = 60450
delete_bin_5_fill = 60451
delete_bin_5_line = 60452
delete_bin_6_fill = 60453
delete_bin_6_line = 60454
delete_bin_7_fill = 60455
delete_bin_7_line = 60456
delete_bin_fill = 60457
delete_bin_line = 60458
delete_column = 60459
delete_row = 60460
device_fill = 60461
device_line = 60462
device_recover_fill = 60463
device_recover_line = 60464
dingding_fill = 60465
dingding_line = 60466
direction_fill = 60467
direction_line = 60468
disc_fill = 60469
disc_line = 60470
discord_fill = 60471
discord_line = 60472
discuss_fill = 60473
discuss_line = 60474
dislike_fill = 60475
dislike_line = 60476
disqus_fill = 60477
disqus_line = 60478
divide_fill = 60479
divide_line = 60480
donut_chart_fill = 60481
donut_chart_line = 60482
door_closed_fill = 60483
door_closed_line = 60484
door_fill = 60485
door_line = 60486
door_lock_box_fill = 60487
door_lock_box_line = 60488
door_lock_fill = 60489
door_lock_line = 60490
door_open_fill = 60491
door_open_line = 60492
dossier_fill = 60493
dossier_line = 60494
douban_fill = 60495
douban_line = 60496
double_quotes_l = 60497
double_quotes_r = 60498
download_2_fill = 60499
download_2_line = 60500
download_cloud_2_fill = 60501
download_cloud_2_line = 60502
download_cloud_fill = 60503
download_cloud_line = 60504
download_fill = 60505
download_line = 60506
draft_fill = 60507
draft_line = 60508
drag_drop_fill = 60509
drag_drop_line = 60510
drag_move_2_fill = 60511
drag_move_2_line = 60512
drag_move_fill = 60513
drag_move_line = 60514
dribbble_fill = 60515
dribbble_line = 60516
drive_fill = 60517
drive_line = 60518
drizzle_fill = 60519
drizzle_line = 60520
drop_fill = 60521
drop_line = 60522
dropbox_fill = 60523
dropbox_line = 60524
dual_sim_1_fill = 60525
dual_sim_1_line = 60526
dual_sim_2_fill = 60527
dual_sim_2_line = 60528
dv_fill = 60529
dv_line = 60530
dvd_fill = 60531
dvd_line = 60532
e_bike_2_fill = 60533
e_bike_2_line = 60534
e_bike_fill = 60535
e_bike_line = 60536
earth_fill = 60537
earth_line = 60538
earthquake_fill = 60539
earthquake_line = 60540
edge_fill = 60541
edge_line = 60542
edit_2_fill = 60543
edit_2_line = 60544
edit_box_fill = 60545
edit_box_line = 60546
edit_circle_fill = 60547
edit_circle_line = 60548
edit_fill = 60549
edit_line = 60550
eject_fill = 60551
eject_line = 60552
emotion_2_fill = 60553
emotion_2_line = 60554
emotion_fill = 60555
emotion_happy_fill = 60556
emotion_happy_line = 60557
emotion_laugh_fill = 60558
emotion_laugh_line = 60559
emotion_line = 60560
emotion_normal_fill = 60561
emotion_normal_line = 60562
emotion_sad_fill = 60563
emotion_sad_line = 60564
emotion_unhappy_fill = 60565
emotion_unhappy_line = 60566
empathize_fill = 60567
empathize_line = 60568
emphasis = 60570
emphasis_cn = 60569
english_input = 60571
equalizer_fill = 60572
equalizer_line = 60573
eraser_fill = 60574
eraser_line = 60575
error_warning_fill = 60576
error_warning_line = 60577
evernote_fill = 60578
evernote_line = 60579
exchange_box_fill = 60580
exchange_box_line = 60581
exchange_cny_fill = 60582
exchange_cny_line = 60583
exchange_dollar_fill = 60584
exchange_dollar_line = 60585
exchange_fill = 60586
exchange_funds_fill = 60587
exchange_funds_line = 60588
exchange_line = 60589
external_link_fill = 60590
external_link_line = 60591
eye_2_fill = 60592
eye_2_line = 60593
eye_close_fill = 60594
eye_close_line = 60595
eye_fill = 60596
eye_line = 60597
eye_off_fill = 60598
eye_off_line = 60599
facebook_box_fill = 60600
facebook_box_line = 60601
facebook_circle_fill = 60602
facebook_circle_line = 60603
facebook_fill = 60604
facebook_line = 60605
fahrenheit_fill = 60606
fahrenheit_line = 60607
feedback_fill = 60608
feedback_line = 60609
file_2_fill = 60610
file_2_line = 60611
file_3_fill = 60612
file_3_line = 60613
file_4_fill = 60614
file_4_line = 60615
file_add_fill = 60616
file_add_line = 60617
file_chart_2_fill = 60618
file_chart_2_line = 60619
file_chart_fill = 60620
file_chart_line = 60621
file_cloud_fill = 60622
file_cloud_line = 60623
file_code_fill = 60624
file_code_line = 60625
file_copy_2_fill = 60626
file_copy_2_line = 60627
file_copy_fill = 60628
file_copy_line = 60629
file_damage_fill = 60630
file_damage_line = 60631
file_download_fill = 60632
file_download_line = 60633
file_edit_fill = 60634
file_edit_line = 60635
file_excel_2_fill = 60636
file_excel_2_line = 60637
file_excel_fill = 60638
file_excel_line = 60639
file_fill = 60640
file_forbid_fill = 60641
file_forbid_line = 60642
file_gif_fill = 60643
file_gif_line = 60644
file_history_fill = 60645
file_history_line = 60646
file_hwp_fill = 60647
file_hwp_line = 60648
file_info_fill = 60649
file_info_line = 60650
file_line = 60651
file_list_2_fill = 60652
file_list_2_line = 60653
file_list_3_fill = 60654
file_list_3_line = 60655
file_list_fill = 60656
file_list_line = 60657
file_lock_fill = 60658
file_lock_line = 60659
file_mark_fill = 60660
file_mark_line = 60661
file_music_fill = 60662
file_music_line = 60663
file_paper_2_fill = 60664
file_paper_2_line = 60665
file_paper_fill = 60666
file_paper_line = 60667
file_pdf_fill = 60668
file_pdf_line = 60669
file_ppt_2_fill = 60670
file_ppt_2_line = 60671
file_ppt_fill = 60672
file_ppt_line = 60673
file_reduce_fill = 60674
file_reduce_line = 60675
file_search_fill = 60676
file_search_line = 60677
file_settings_fill = 60678
file_settings_line = 60679
file_shield_2_fill = 60680
file_shield_2_line = 60681
file_shield_fill = 60682
file_shield_line = 60683
file_shred_fill = 60684
file_shred_line = 60685
file_text_fill = 60686
file_text_line = 60687
file_transfer_fill = 60688
file_transfer_line = 60689
file_unknow_fill = 60690
file_unknow_line = 60691
file_upload_fill = 60692
file_upload_line = 60693
file_user_fill = 60694
file_user_line = 60695
file_warning_fill = 60696
file_warning_line = 60697
file_word_2_fill = 60698
file_word_2_line = 60699
file_word_fill = 60700
file_word_line = 60701
file_zip_fill = 60702
file_zip_line = 60703
film_fill = 60704
film_line = 60705
filter_2_fill = 60706
filter_2_line = 60707
filter_3_fill = 60708
filter_3_line = 60709
filter_fill = 60710
filter_line = 60711
filter_off_fill = 60712
filter_off_line = 60713
find_replace_fill = 60714
find_replace_line = 60715
finder_fill = 60716
finder_line = 60717
fingerprint_2_fill = 60718
fingerprint_2_line = 60719
fingerprint_fill = 60720
fingerprint_line = 60721
fire_fill = 60722
fire_line = 60723
firefox_fill = 60724
firefox_line = 60725
first_aid_kit_fill = 60726
first_aid_kit_line = 60727
flag_2_fill = 60728
flag_2_line = 60729
flag_fill = 60730
flag_line = 60731
flashlight_fill = 60732
flashlight_line = 60733
flask_fill = 60734
flask_line = 60735
flight_land_fill = 60736
flight_land_line = 60737
flight_takeoff_fill = 60738
flight_takeoff_line = 60739
flood_fill = 60740
flood_line = 60741
flow_chart = 60742
flutter_fill = 60743
flutter_line = 60744
focus_2_fill = 60745
focus_2_line = 60746
focus_3_fill = 60747
focus_3_line = 60748
focus_fill = 60749
focus_line = 60750
foggy_fill = 60751
foggy_line = 60752
folder_2_fill = 60753
folder_2_line = 60754
folder_3_fill = 60755
folder_3_line = 60756
folder_4_fill = 60757
folder_4_line = 60758
folder_5_fill = 60759
folder_5_line = 60760
folder_add_fill = 60761
folder_add_line = 60762
folder_chart_2_fill = 60763
folder_chart_2_line = 60764
folder_chart_fill = 60765
folder_chart_line = 60766
folder_download_fill = 60767
folder_download_line = 60768
folder_fill = 60769
folder_forbid_fill = 60770
folder_forbid_line = 60771
folder_history_fill = 60772
folder_history_line = 60773
folder_info_fill = 60774
folder_info_line = 60775
folder_keyhole_fill = 60776
folder_keyhole_line = 60777
folder_line = 60778
folder_lock_fill = 60779
folder_lock_line = 60780
folder_music_fill = 60781
folder_music_line = 60782
folder_open_fill = 60783
folder_open_line = 60784
folder_received_fill = 60785
folder_received_line = 60786
folder_reduce_fill = 60787
folder_reduce_line = 60788
folder_settings_fill = 60789
folder_settings_line = 60790
folder_shared_fill = 60791
folder_shared_line = 60792
folder_shield_2_fill = 60793
folder_shield_2_line = 60794
folder_shield_fill = 60795
folder_shield_line = 60796
folder_transfer_fill = 60797
folder_transfer_line = 60798
folder_unknow_fill = 60799
folder_unknow_line = 60800
folder_upload_fill = 60801
folder_upload_line = 60802
folder_user_fill = 60803
folder_user_line = 60804
folder_warning_fill = 60805
folder_warning_line = 60806
folder_zip_fill = 60807
folder_zip_line = 60808
folders_fill = 60809
folders_line = 60810
font_color = 60811
font_size = 60813
font_size_2 = 60812
football_fill = 60814
football_line = 60815
footprint_fill = 60816
footprint_line = 60817
forbid_2_fill = 60818
forbid_2_line = 60819
forbid_fill = 60820
forbid_line = 60821
format_clear = 60822
fridge_fill = 60823
fridge_line = 60824
fullscreen_exit_fill = 60825
fullscreen_exit_line = 60826
fullscreen_fill = 60827
fullscreen_line = 60828
function_fill = 60829
function_line = 60830
functions = 60831
funds_box_fill = 60832
funds_box_line = 60833
funds_fill = 60834
funds_line = 60835
gallery_fill = 60836
gallery_line = 60837
gallery_upload_fill = 60838
gallery_upload_line = 60839
game_fill = 60840
game_line = 60841
gamepad_fill = 60842
gamepad_line = 60843
gas_station_fill = 60844
gas_station_line = 60845
gatsby_fill = 60846
gatsby_line = 60847
genderless_fill = 60848
genderless_line = 60849
ghost_2_fill = 60850
ghost_2_line = 60851
ghost_fill = 60852
ghost_line = 60853
ghost_smile_fill = 60854
ghost_smile_line = 60855
gift_2_fill = 60856
gift_2_line = 60857
gift_fill = 60858
gift_line = 60859
git_branch_fill = 60860
git_branch_line = 60861
git_commit_fill = 60862
git_commit_line = 60863
git_merge_fill = 60864
git_merge_line = 60865
git_pull_request_fill = 60866
git_pull_request_line = 60867
git_repository_commits_fill = 60868
git_repository_commits_line = 60869
git_repository_fill = 60870
git_repository_line = 60871
git_repository_private_fill = 60872
git_repository_private_line = 60873
github_fill = 60874
github_line = 60875
gitlab_fill = 60876
gitlab_line = 60877
global_fill = 60878
global_line = 60879
globe_fill = 60880
globe_line = 60881
goblet_fill = 60882
goblet_line = 60883
google_fill = 60884
google_line = 60885
google_play_fill = 60886
google_play_line = 60887
government_fill = 60888
government_line = 60889
gps_fill = 60890
gps_line = 60891
gradienter_fill = 60892
gradienter_line = 60893
grid_fill = 60894
grid_line = 60895
group_2_fill = 60896
group_2_line = 60897
group_fill = 60898
group_line = 60899
guide_fill = 60900
guide_line = 60901
h_1 = 60902
h_2 = 60903
h_3 = 60904
h_4 = 60905
h_5 = 60906
h_6 = 60907
hail_fill = 60908
hail_line = 60909
hammer_fill = 60910
hammer_line = 60911
hand_coin_fill = 60912
hand_coin_line = 60913
hand_heart_fill = 60914
hand_heart_line = 60915
hand_sanitizer_fill = 60916
hand_sanitizer_line = 60917
handbag_fill = 60918
handbag_line = 60919
hard_drive_2_fill = 60920
hard_drive_2_line = 60921
hard_drive_fill = 60922
hard_drive_line = 60923
hashtag = 60924
haze_2_fill = 60925
haze_2_line = 60926
haze_fill = 60927
haze_line = 60928
hd_fill = 60929
hd_line = 60930
heading = 60931
headphone_fill = 60932
headphone_line = 60933
health_book_fill = 60934
health_book_line = 60935
heart_2_fill = 60936
heart_2_line = 60937
heart_3_fill = 60938
heart_3_line = 60939
heart_add_fill = 60940
heart_add_line = 60941
heart_fill = 60942
heart_line = 60943
heart_pulse_fill = 60944
heart_pulse_line = 60945
hearts_fill = 60946
hearts_line = 60947
heavy_showers_fill = 60948
heavy_showers_line = 60949
history_fill = 60950
history_line = 60951
home_2_fill = 60952
home_2_line = 60953
home_3_fill = 60954
home_3_line = 60955
home_4_fill = 60956
home_4_line = 60957
home_5_fill = 60958
home_5_line = 60959
home_6_fill = 60960
home_6_line = 60961
home_7_fill = 60962
home_7_line = 60963
home_8_fill = 60964
home_8_line = 60965
home_fill = 60966
home_gear_fill = 60967
home_gear_line = 60968
home_heart_fill = 60969
home_heart_line = 60970
home_line = 60971
home_smile_2_fill = 60972
home_smile_2_line = 60973
home_smile_fill = 60974
home_smile_line = 60975
home_wifi_fill = 60976
home_wifi_line = 60977
honor_of_kings_fill = 60978
honor_of_kings_line = 60979
honour_fill = 60980
honour_line = 60981
hospital_fill = 60982
hospital_line = 60983
hotel_bed_fill = 60984
hotel_bed_line = 60985
hotel_fill = 60986
hotel_line = 60987
hotspot_fill = 60988
hotspot_line = 60989
hq_fill = 60990
hq_line = 60991
html5_fill = 60992
html5_line = 60993
ie_fill = 60994
ie_line = 60995
image_2_fill = 60996
image_2_line = 60997
image_add_fill = 60998
image_add_line = 60999
image_edit_fill = 61000
image_edit_line = 61001
image_fill = 61002
image_line = 61003
inbox_archive_fill = 61004
inbox_archive_line = 61005
inbox_fill = 61006
inbox_line = 61007
inbox_unarchive_fill = 61008
inbox_unarchive_line = 61009
increase_decrease_fill = 61010
increase_decrease_line = 61011
indent_decrease = 61012
indent_increase = 61013
indeterminate_circle_fill = 61014
indeterminate_circle_line = 61015
information_fill = 61016
information_line = 61017
infrared_thermometer_fill = 61018
infrared_thermometer_line = 61019
ink_bottle_fill = 61020
ink_bottle_line = 61021
input_cursor_move = 61022
input_method_fill = 61023
input_method_line = 61024
insert_column_left = 61025
insert_column_right = 61026
insert_row_bottom = 61027
insert_row_top = 61028
instagram_fill = 61029
instagram_line = 61030
install_fill = 61031
install_line = 61032
invision_fill = 61033
invision_line = 61034
italic = 61035
kakao_talk_fill = 61036
kakao_talk_line = 61037
key_2_fill = 61038
key_2_line = 61039
key_fill = 61040
key_line = 61041
keyboard_box_fill = 61042
keyboard_box_line = 61043
keyboard_fill = 61044
keyboard_line = 61045
keynote_fill = 61046
keynote_line = 61047
knife_blood_fill = 61048
knife_blood_line = 61049
knife_fill = 61050
knife_line = 61051
landscape_fill = 61052
landscape_line = 61053
layout_2_fill = 61054
layout_2_line = 61055
layout_3_fill = 61056
layout_3_line = 61057
layout_4_fill = 61058
layout_4_line = 61059
layout_5_fill = 61060
layout_5_line = 61061
layout_6_fill = 61062
layout_6_line = 61063
layout_bottom_2_fill = 61064
layout_bottom_2_line = 61065
layout_bottom_fill = 61066
layout_bottom_line = 61067
layout_column_fill = 61068
layout_column_line = 61069
layout_fill = 61070
layout_grid_fill = 61071
layout_grid_line = 61072
layout_left_2_fill = 61073
layout_left_2_line = 61074
layout_left_fill = 61075
layout_left_line = 61076
layout_line = 61077
layout_masonry_fill = 61078
layout_masonry_line = 61079
layout_right_2_fill = 61080
layout_right_2_line = 61081
layout_right_fill = 61082
layout_right_line = 61083
layout_row_fill = 61084
layout_row_line = 61085
layout_top_2_fill = 61086
layout_top_2_line = 61087
layout_top_fill = 61088
layout_top_line = 61089
leaf_fill = 61090
leaf_line = 61091
lifebuoy_fill = 61092
lifebuoy_line = 61093
lightbulb_fill = 61094
lightbulb_flash_fill = 61095
lightbulb_flash_line = 61096
lightbulb_line = 61097
line_chart_fill = 61098
line_chart_line = 61099
line_fill = 61100
line_height = 61101
line_line = 61102
link = 61106
link_m = 61103
link_unlink = 61105
link_unlink_m = 61104
linkedin_box_fill = 61107
linkedin_box_line = 61108
linkedin_fill = 61109
linkedin_line = 61110
links_fill = 61111
links_line = 61112
list_check = 61114
list_check_2 = 61113
list_ordered = 61115
list_settings_fill = 61116
list_settings_line = 61117
list_unordered = 61118
live_fill = 61119
live_line = 61120
loader_2_fill = 61121
loader_2_line = 61122
loader_3_fill = 61123
loader_3_line = 61124
loader_4_fill = 61125
loader_4_line = 61126
loader_5_fill = 61127
loader_5_line = 61128
loader_fill = 61129
loader_line = 61130
lock_2_fill = 61131
lock_2_line = 61132
lock_fill = 61133
lock_line = 61134
lock_password_fill = 61135
lock_password_line = 61136
lock_unlock_fill = 61137
lock_unlock_line = 61138
login_box_fill = 61139
login_box_line = 61140
login_circle_fill = 61141
login_circle_line = 61142
logout_box_fill = 61143
logout_box_line = 61144
logout_box_r_fill = 61145
logout_box_r_line = 61146
logout_circle_fill = 61147
logout_circle_line = 61148
logout_circle_r_fill = 61149
logout_circle_r_line = 61150
luggage_cart_fill = 61151
luggage_cart_line = 61152
luggage_deposit_fill = 61153
luggage_deposit_line = 61154
lungs_fill = 61155
lungs_line = 61156
mac_fill = 61157
mac_line = 61158
macbook_fill = 61159
macbook_line = 61160
magic_fill = 61161
magic_line = 61162
mail_add_fill = 61163
mail_add_line = 61164
mail_check_fill = 61165
mail_check_line = 61166
mail_close_fill = 61167
mail_close_line = 61168
mail_download_fill = 61169
mail_download_line = 61170
mail_fill = 61171
mail_forbid_fill = 61172
mail_forbid_line = 61173
mail_line = 61174
mail_lock_fill = 61175
mail_lock_line = 61176
mail_open_fill = 61177
mail_open_line = 61178
mail_send_fill = 61179
mail_send_line = 61180
mail_settings_fill = 61181
mail_settings_line = 61182
mail_star_fill = 61183
mail_star_line = 61184
mail_unread_fill = 61185
mail_unread_line = 61186
mail_volume_fill = 61187
mail_volume_line = 61188
map_2_fill = 61189
map_2_line = 61190
map_fill = 61191
map_line = 61192
map_pin_2_fill = 61193
map_pin_2_line = 61194
map_pin_3_fill = 61195
map_pin_3_line = 61196
map_pin_4_fill = 61197
map_pin_4_line = 61198
map_pin_5_fill = 61199
map_pin_5_line = 61200
map_pin_add_fill = 61201
map_pin_add_line = 61202
map_pin_fill = 61203
map_pin_line = 61204
map_pin_range_fill = 61205
map_pin_range_line = 61206
map_pin_time_fill = 61207
map_pin_time_line = 61208
map_pin_user_fill = 61209
map_pin_user_line = 61210
mark_pen_fill = 61211
mark_pen_line = 61212
markdown_fill = 61213
markdown_line = 61214
markup_fill = 61215
markup_line = 61216
mastercard_fill = 61217
mastercard_line = 61218
mastodon_fill = 61219
mastodon_line = 61220
medal_2_fill = 61221
medal_2_line = 61222
medal_fill = 61223
medal_line = 61224
medicine_bottle_fill = 61225
medicine_bottle_line = 61226
medium_fill = 61227
medium_line = 61228
men_fill = 61229
men_line = 61230
mental_health_fill = 61231
mental_health_line = 61232
menu_2_fill = 61233
menu_2_line = 61234
menu_3_fill = 61235
menu_3_line = 61236
menu_4_fill = 61237
menu_4_line = 61238
menu_5_fill = 61239
menu_5_line = 61240
menu_add_fill = 61241
menu_add_line = 61242
menu_fill = 61243
menu_fold_fill = 61244
menu_fold_line = 61245
menu_line = 61246
menu_unfold_fill = 61247
menu_unfold_line = 61248
merge_cells_horizontal = 61249
merge_cells_vertical = 61250
message_2_fill = 61251
message_2_line = 61252
message_3_fill = 61253
message_3_line = 61254
message_fill = 61255
message_line = 61256
messenger_fill = 61257
messenger_line = 61258
meteor_fill = 61259
meteor_line = 61260
mic_2_fill = 61261
mic_2_line = 61262
mic_fill = 61263
mic_line = 61264
mic_off_fill = 61265
mic_off_line = 61266
mickey_fill = 61267
mickey_line = 61268
microscope_fill = 61269
microscope_line = 61270
microsoft_fill = 61271
microsoft_line = 61272
mind_map = 61273
mini_program_fill = 61274
mini_program_line = 61275
mist_fill = 61276
mist_line = 61277
money_cny_box_fill = 61278
money_cny_box_line = 61279
money_cny_circle_fill = 61280
money_cny_circle_line = 61281
money_dollar_box_fill = 61282
money_dollar_box_line = 61283
money_dollar_circle_fill = 61284
money_dollar_circle_line = 61285
money_euro_box_fill = 61286
money_euro_box_line = 61287
money_euro_circle_fill = 61288
money_euro_circle_line = 61289
money_pound_box_fill = 61290
money_pound_box_line = 61291
money_pound_circle_fill = 61292
money_pound_circle_line = 61293
moon_clear_fill = 61294
moon_clear_line = 61295
moon_cloudy_fill = 61296
moon_cloudy_line = 61297
moon_fill = 61298
moon_foggy_fill = 61299
moon_foggy_line = 61300
moon_line = 61301
more_2_fill = 61302
more_2_line = 61303
more_fill = 61304
more_line = 61305
motorbike_fill = 61306
motorbike_line = 61307
mouse_fill = 61308
mouse_line = 61309
movie_2_fill = 61310
movie_2_line = 61311
movie_fill = 61312
movie_line = 61313
music_2_fill = 61314
music_2_line = 61315
music_fill = 61316
music_line = 61317
mv_fill = 61318
mv_line = 61319
navigation_fill = 61320
navigation_line = 61321
netease_cloud_music_fill = 61322
netease_cloud_music_line = 61323
netflix_fill = 61324
netflix_line = 61325
newspaper_fill = 61326
newspaper_line = 61327
node_tree = 61328
notification_2_fill = 61329
notification_2_line = 61330
notification_3_fill = 61331
notification_3_line = 61332
notification_4_fill = 61333
notification_4_line = 61334
notification_badge_fill = 61335
notification_badge_line = 61336
notification_fill = 61337
notification_line = 61338
notification_off_fill = 61339
notification_off_line = 61340
npmjs_fill = 61341
npmjs_line = 61342
number_0 = 61343
number_1 = 61344
number_2 = 61345
number_3 = 61346
number_4 = 61347
number_5 = 61348
number_6 = 61349
number_7 = 61350
number_8 = 61351
number_9 = 61352
numbers_fill = 61353
numbers_line = 61354
nurse_fill = 61355
nurse_line = 61356
oil_fill = 61357
oil_line = 61358
omega = 61359
open_arm_fill = 61360
open_arm_line = 61361
open_source_fill = 61362
open_source_line = 61363
opera_fill = 61364
opera_line = 61365
order_play_fill = 61366
order_play_line = 61367
organization_chart = 61368
outlet_2_fill = 61369
outlet_2_line = 61370
outlet_fill = 61371
outlet_line = 61372
page_separator = 61373
pages_fill = 61374
pages_line = 61375
paint_brush_fill = 61376
paint_brush_line = 61377
paint_fill = 61378
paint_line = 61379
palette_fill = 61380
palette_line = 61381
pantone_fill = 61382
pantone_line = 61383
paragraph = 61384
parent_fill = 61385
parent_line = 61386
parentheses_fill = 61387
parentheses_line = 61388
parking_box_fill = 61389
parking_box_line = 61390
parking_fill = 61391
parking_line = 61392
passport_fill = 61393
passport_line = 61394
patreon_fill = 61395
patreon_line = 61396
pause_circle_fill = 61397
pause_circle_line = 61398
pause_fill = 61399
pause_line = 61400
pause_mini_fill = 61401
pause_mini_line = 61402
paypal_fill = 61403
paypal_line = 61404
pen_nib_fill = 61405
pen_nib_line = 61406
pencil_fill = 61407
pencil_line = 61408
pencil_ruler_2_fill = 61409
pencil_ruler_2_line = 61410
pencil_ruler_fill = 61411
pencil_ruler_line = 61412
percent_fill = 61413
percent_line = 61414
phone_camera_fill = 61415
phone_camera_line = 61416
phone_fill = 61417
phone_find_fill = 61418
phone_find_line = 61419
phone_line = 61420
phone_lock_fill = 61421
phone_lock_line = 61422
picture_in_picture_2_fill = 61423
picture_in_picture_2_line = 61424
picture_in_picture_exit_fill = 61425
picture_in_picture_exit_line = 61426
picture_in_picture_fill = 61427
picture_in_picture_line = 61428
pie_chart_2_fill = 61429
pie_chart_2_line = 61430
pie_chart_box_fill = 61431
pie_chart_box_line = 61432
pie_chart_fill = 61433
pie_chart_line = 61434
pin_distance_fill = 61435
pin_distance_line = 61436
ping_pong_fill = 61437
ping_pong_line = 61438
pinterest_fill = 61439
pinterest_line = 61440
pinyin_input = 61441
pixelfed_fill = 61442
pixelfed_line = 61443
plane_fill = 61444
plane_line = 61445
plant_fill = 61446
plant_line = 61447
play_circle_fill = 61448
play_circle_line = 61449
play_fill = 61450
play_line = 61451
play_list_2_fill = 61452
play_list_2_line = 61453
play_list_add_fill = 61454
play_list_add_line = 61455
play_list_fill = 61456
play_list_line = 61457
play_mini_fill = 61458
play_mini_line = 61459
playstation_fill = 61460
playstation_line = 61461
plug_2_fill = 61462
plug_2_line = 61463
plug_fill = 61464
plug_line = 61465
polaroid_2_fill = 61466
polaroid_2_line = 61467
polaroid_fill = 61468
polaroid_line = 61469
police_car_fill = 61470
police_car_line = 61471
price_tag_2_fill = 61472
price_tag_2_line = 61473
price_tag_3_fill = 61474
price_tag_3_line = 61475
price_tag_fill = 61476
price_tag_line = 61477
printer_cloud_fill = 61478
printer_cloud_line = 61479
printer_fill = 61480
printer_line = 61481
product_hunt_fill = 61482
product_hunt_line = 61483
profile_fill = 61484
profile_line = 61485
projector_2_fill = 61486
projector_2_line = 61487
projector_fill = 61488
projector_line = 61489
psychotherapy_fill = 61490
psychotherapy_line = 61491
pulse_fill = 61492
pulse_line = 61493
pushpin_2_fill = 61494
pushpin_2_line = 61495
pushpin_fill = 61496
pushpin_line = 61497
qq_fill = 61498
qq_line = 61499
qr_code_fill = 61500
qr_code_line = 61501
qr_scan_2_fill = 61502
qr_scan_2_line = 61503
qr_scan_fill = 61504
qr_scan_line = 61505
question_answer_fill = 61506
question_answer_line = 61507
question_fill = 61508
question_line = 61509
question_mark = 61510
questionnaire_fill = 61511
questionnaire_line = 61512
quill_pen_fill = 61513
quill_pen_line = 61514
radar_fill = 61515
radar_line = 61516
radio_2_fill = 61517
radio_2_line = 61518
radio_button_fill = 61519
radio_button_line = 61520
radio_fill = 61521
radio_line = 61522
rainbow_fill = 61523
rainbow_line = 61524
rainy_fill = 61525
rainy_line = 61526
reactjs_fill = 61527
reactjs_line = 61528
record_circle_fill = 61529
record_circle_line = 61530
record_mail_fill = 61531
record_mail_line = 61532
recycle_fill = 61533
recycle_line = 61534
red_packet_fill = 61535
red_packet_line = 61536
reddit_fill = 61537
reddit_line = 61538
refresh_fill = 61539
refresh_line = 61540
refund_2_fill = 61541
refund_2_line = 61542
refund_fill = 61543
refund_line = 61544
registered_fill = 61545
registered_line = 61546
remixicon_fill = 61547
remixicon_line = 61548
remote_control_2_fill = 61549
remote_control_2_line = 61550
remote_control_fill = 61551
remote_control_line = 61552
repeat_2_fill = 61553
repeat_2_line = 61554
repeat_fill = 61555
repeat_line = 61556
repeat_one_fill = 61557
repeat_one_line = 61558
reply_all_fill = 61559
reply_all_line = 61560
reply_fill = 61561
reply_line = 61562
reserved_fill = 61563
reserved_line = 61564
rest_time_fill = 61565
rest_time_line = 61566
restart_fill = 61567
restart_line = 61568
restaurant_2_fill = 61569
restaurant_2_line = 61570
restaurant_fill = 61571
restaurant_line = 61572
rewind_fill = 61573
rewind_line = 61574
rewind_mini_fill = 61575
rewind_mini_line = 61576
rhythm_fill = 61577
rhythm_line = 61578
riding_fill = 61579
riding_line = 61580
road_map_fill = 61581
road_map_line = 61582
roadster_fill = 61583
roadster_line = 61584
robot_fill = 61585
robot_line = 61586
rocket_2_fill = 61587
rocket_2_line = 61588
rocket_fill = 61589
rocket_line = 61590
rotate_lock_fill = 61591
rotate_lock_line = 61592
rounded_corner = 61593
route_fill = 61594
route_line = 61595
router_fill = 61596
router_line = 61597
rss_fill = 61598
rss_line = 61599
ruler_2_fill = 61600
ruler_2_line = 61601
ruler_fill = 61602
ruler_line = 61603
run_fill = 61604
run_line = 61605
safari_fill = 61606
safari_line = 61607
safe_2_fill = 61608
safe_2_line = 61609
safe_fill = 61610
safe_line = 61611
sailboat_fill = 61612
sailboat_line = 61613
save_2_fill = 61614
save_2_line = 61615
save_3_fill = 61616
save_3_line = 61617
save_fill = 61618
save_line = 61619
scales_2_fill = 61620
scales_2_line = 61621
scales_3_fill = 61622
scales_3_line = 61623
scales_fill = 61624
scales_line = 61625
scan_2_fill = 61626
scan_2_line = 61627
scan_fill = 61628
scan_line = 61629
scissors_2_fill = 61630
scissors_2_line = 61631
scissors_cut_fill = 61632
scissors_cut_line = 61633
scissors_fill = 61634
scissors_line = 61635
screenshot_2_fill = 61636
screenshot_2_line = 61637
screenshot_fill = 61638
screenshot_line = 61639
sd_card_fill = 61640
sd_card_line = 61641
sd_card_mini_fill = 61642
sd_card_mini_line = 61643
search_2_fill = 61644
search_2_line = 61645
search_eye_fill = 61646
search_eye_line = 61647
search_fill = 61648
search_line = 61649
secure_payment_fill = 61650
secure_payment_line = 61651
seedling_fill = 61652
seedling_line = 61653
send_backward = 61654
send_plane_2_fill = 61655
send_plane_2_line = 61656
send_plane_fill = 61657
send_plane_line = 61658
send_to_back = 61659
sensor_fill = 61660
sensor_line = 61661
separator = 61662
server_fill = 61663
server_line = 61664
service_fill = 61665
service_line = 61666
settings_2_fill = 61667
settings_2_line = 61668
settings_3_fill = 61669
settings_3_line = 61670
settings_4_fill = 61671
settings_4_line = 61672
settings_5_fill = 61673
settings_5_line = 61674
settings_6_fill = 61675
settings_6_line = 61676
settings_fill = 61677
settings_line = 61678
shape_2_fill = 61679
shape_2_line = 61680
shape_fill = 61681
shape_line = 61682
share_box_fill = 61683
share_box_line = 61684
share_circle_fill = 61685
share_circle_line = 61686
share_fill = 61687
share_forward_2_fill = 61688
share_forward_2_line = 61689
share_forward_box_fill = 61690
share_forward_box_line = 61691
share_forward_fill = 61692
share_forward_line = 61693
share_line = 61694
shield_check_fill = 61695
shield_check_line = 61696
shield_cross_fill = 61697
shield_cross_line = 61698
shield_fill = 61699
shield_flash_fill = 61700
shield_flash_line = 61701
shield_keyhole_fill = 61702
shield_keyhole_line = 61703
shield_line = 61704
shield_star_fill = 61705
shield_star_line = 61706
shield_user_fill = 61707
shield_user_line = 61708
ship_2_fill = 61709
ship_2_line = 61710
ship_fill = 61711
ship_line = 61712
shirt_fill = 61713
shirt_line = 61714
shopping_bag_2_fill = 61715
shopping_bag_2_line = 61716
shopping_bag_3_fill = 61717
shopping_bag_3_line = 61718
shopping_bag_fill = 61719
shopping_bag_line = 61720
shopping_basket_2_fill = 61721
shopping_basket_2_line = 61722
shopping_basket_fill = 61723
shopping_basket_line = 61724
shopping_cart_2_fill = 61725
shopping_cart_2_line = 61726
shopping_cart_fill = 61727
shopping_cart_line = 61728
showers_fill = 61729
showers_line = 61730
shuffle_fill = 61731
shuffle_line = 61732
shut_down_fill = 61733
shut_down_line = 61734
side_bar_fill = 61735
side_bar_line = 61736
signal_tower_fill = 61737
signal_tower_line = 61738
signal_wifi_1_fill = 61739
signal_wifi_1_line = 61740
signal_wifi_2_fill = 61741
signal_wifi_2_line = 61742
signal_wifi_3_fill = 61743
signal_wifi_3_line = 61744
signal_wifi_error_fill = 61745
signal_wifi_error_line = 61746
signal_wifi_fill = 61747
signal_wifi_line = 61748
signal_wifi_off_fill = 61749
signal_wifi_off_line = 61750
sim_card_2_fill = 61751
sim_card_2_line = 61752
sim_card_fill = 61753
sim_card_line = 61754
single_quotes_l = 61755
single_quotes_r = 61756
sip_fill = 61757
sip_line = 61758
skip_back_fill = 61759
skip_back_line = 61760
skip_back_mini_fill = 61761
skip_back_mini_line = 61762
skip_forward_fill = 61763
skip_forward_line = 61764
skip_forward_mini_fill = 61765
skip_forward_mini_line = 61766
skull_2_fill = 61767
skull_2_line = 61768
skull_fill = 61769
skull_line = 61770
skype_fill = 61771
skype_line = 61772
slack_fill = 61773
slack_line = 61774
slice_fill = 61775
slice_line = 61776
slideshow_2_fill = 61777
slideshow_2_line = 61778
slideshow_3_fill = 61779
slideshow_3_line = 61780
slideshow_4_fill = 61781
slideshow_4_line = 61782
slideshow_fill = 61783
slideshow_line = 61784
smartphone_fill = 61785
smartphone_line = 61786
snapchat_fill = 61787
snapchat_line = 61788
snowy_fill = 61789
snowy_line = 61790
sort_asc = 61791
sort_desc = 61792
sound_module_fill = 61793
sound_module_line = 61794
soundcloud_fill = 61795
soundcloud_line = 61796
space = 61799
space_ship_fill = 61797
space_ship_line = 61798
spam_2_fill = 61800
spam_2_line = 61801
spam_3_fill = 61802
spam_3_line = 61803
spam_fill = 61804
spam_line = 61805
speaker_2_fill = 61806
speaker_2_line = 61807
speaker_3_fill = 61808
speaker_3_line = 61809
speaker_fill = 61810
speaker_line = 61811
spectrum_fill = 61812
spectrum_line = 61813
speed_fill = 61814
speed_line = 61815
speed_mini_fill = 61816
speed_mini_line = 61817
split_cells_horizontal = 61818
split_cells_vertical = 61819
spotify_fill = 61820
spotify_line = 61821
spy_fill = 61822
spy_line = 61823
stack_fill = 61824
stack_line = 61825
stack_overflow_fill = 61826
stack_overflow_line = 61827
stackshare_fill = 61828
stackshare_line = 61829
star_fill = 61830
star_half_fill = 61831
star_half_line = 61832
star_half_s_fill = 61833
star_half_s_line = 61834
star_line = 61835
star_s_fill = 61836
star_s_line = 61837
star_smile_fill = 61838
star_smile_line = 61839
steam_fill = 61840
steam_line = 61841
steering_2_fill = 61842
steering_2_line = 61843
steering_fill = 61844
steering_line = 61845
stethoscope_fill = 61846
stethoscope_line = 61847
sticky_note_2_fill = 61848
sticky_note_2_line = 61849
sticky_note_fill = 61850
sticky_note_line = 61851
stock_fill = 61852
stock_line = 61853
stop_circle_fill = 61854
stop_circle_line = 61855
stop_fill = 61856
stop_line = 61857
stop_mini_fill = 61858
stop_mini_line = 61859
store_2_fill = 61860
store_2_line = 61861
store_3_fill = 61862
store_3_line = 61863
store_fill = 61864
store_line = 61865
strikethrough = 61867
strikethrough_2 = 61866
subscript = 61869
subscript_2 = 61868
subtract_fill = 61870
subtract_line = 61871
subway_fill = 61872
subway_line = 61873
subway_wifi_fill = 61874
subway_wifi_line = 61875
suitcase_2_fill = 61876
suitcase_2_line = 61877
suitcase_3_fill = 61878
suitcase_3_line = 61879
suitcase_fill = 61880
suitcase_line = 61881
sun_cloudy_fill = 61882
sun_cloudy_line = 61883
sun_fill = 61884
sun_foggy_fill = 61885
sun_foggy_line = 61886
sun_line = 61887
superscript = 61889
superscript_2 = 61888
surgical_mask_fill = 61890
surgical_mask_line = 61891
surround_sound_fill = 61892
surround_sound_line = 61893
survey_fill = 61894
survey_line = 61895
swap_box_fill = 61896
swap_box_line = 61897
swap_fill = 61898
swap_line = 61899
switch_fill = 61900
switch_line = 61901
sword_fill = 61902
sword_line = 61903
syringe_fill = 61904
syringe_line = 61905
t_box_fill = 61906
t_box_line = 61907
t_shirt_2_fill = 61908
t_shirt_2_line = 61909
t_shirt_air_fill = 61910
t_shirt_air_line = 61911
t_shirt_fill = 61912
t_shirt_line = 61913
table_2 = 61914
table_alt_fill = 61915
table_alt_line = 61916
table_fill = 61917
table_line = 61918
tablet_fill = 61919
tablet_line = 61920
takeaway_fill = 61921
takeaway_line = 61922
taobao_fill = 61923
taobao_line = 61924
tape_fill = 61925
tape_line = 61926
task_fill = 61927
task_line = 61928
taxi_fill = 61929
taxi_line = 61930
taxi_wifi_fill = 61931
taxi_wifi_line = 61932
team_fill = 61933
team_line = 61934
telegram_fill = 61935
telegram_line = 61936
temp_cold_fill = 61937
temp_cold_line = 61938
temp_hot_fill = 61939
temp_hot_line = 61940
terminal_box_fill = 61941
terminal_box_line = 61942
terminal_fill = 61943
terminal_line = 61944
terminal_window_fill = 61945
terminal_window_line = 61946
test_tube_fill = 61947
test_tube_line = 61948
text = 61953
text_direction_l = 61949
text_direction_r = 61950
text_spacing = 61951
text_wrap = 61952
thermometer_fill = 61954
thermometer_line = 61955
thumb_down_fill = 61956
thumb_down_line = 61957
thumb_up_fill = 61958
thumb_up_line = 61959
thunderstorms_fill = 61960
thunderstorms_line = 61961
ticket_2_fill = 61962
ticket_2_line = 61963
ticket_fill = 61964
ticket_line = 61965
time_fill = 61966
time_line = 61967
timer_2_fill = 61968
timer_2_line = 61969
timer_fill = 61970
timer_flash_fill = 61971
timer_flash_line = 61972
timer_line = 61973
todo_fill = 61974
todo_line = 61975
toggle_fill = 61976
toggle_line = 61977
tools_fill = 61978
tools_line = 61979
tornado_fill = 61980
tornado_line = 61981
trademark_fill = 61982
trademark_line = 61983
traffic_light_fill = 61984
traffic_light_line = 61985
train_fill = 61986
train_line = 61987
train_wifi_fill = 61988
train_wifi_line = 61989
translate = 61991
translate_2 = 61990
travesti_fill = 61992
travesti_line = 61993
treasure_map_fill = 61994
treasure_map_line = 61995
trello_fill = 61996
trello_line = 61997
trophy_fill = 61998
trophy_line = 61999
truck_fill = 62000
truck_line = 62001
tumblr_fill = 62002
tumblr_line = 62003
tv_2_fill = 62004
tv_2_line = 62005
tv_fill = 62006
tv_line = 62007
twitch_fill = 62008
twitch_line = 62009
twitter_fill = 62010
twitter_line = 62011
typhoon_fill = 62012
typhoon_line = 62013
u_disk_fill = 62014
u_disk_line = 62015
ubuntu_fill = 62016
ubuntu_line = 62017
umbrella_fill = 62018
umbrella_line = 62019
underline = 62020
uninstall_fill = 62021
uninstall_line = 62022
unsplash_fill = 62023
unsplash_line = 62024
upload_2_fill = 62025
upload_2_line = 62026
upload_cloud_2_fill = 62027
upload_cloud_2_line = 62028
upload_cloud_fill = 62029
upload_cloud_line = 62030
upload_fill = 62031
upload_line = 62032
usb_fill = 62033
usb_line = 62034
user_2_fill = 62035
user_2_line = 62036
user_3_fill = 62037
user_3_line = 62038
user_4_fill = 62039
user_4_line = 62040
user_5_fill = 62041
user_5_line = 62042
user_6_fill = 62043
user_6_line = 62044
user_add_fill = 62045
user_add_line = 62046
user_fill = 62047
user_follow_fill = 62048
user_follow_line = 62049
user_heart_fill = 62050
user_heart_line = 62051
user_line = 62052
user_location_fill = 62053
user_location_line = 62054
user_received_2_fill = 62055
user_received_2_line = 62056
user_received_fill = 62057
user_received_line = 62058
user_search_fill = 62059
user_search_line = 62060
user_settings_fill = 62061
user_settings_line = 62062
user_shared_2_fill = 62063
user_shared_2_line = 62064
user_shared_fill = 62065
user_shared_line = 62066
user_smile_fill = 62067
user_smile_line = 62068
user_star_fill = 62069
user_star_line = 62070
user_unfollow_fill = 62071
user_unfollow_line = 62072
user_voice_fill = 62073
user_voice_line = 62074
video_add_fill = 62075
video_add_line = 62076
video_chat_fill = 62077
video_chat_line = 62078
video_download_fill = 62079
video_download_line = 62080
video_fill = 62081
video_line = 62082
video_upload_fill = 62083
video_upload_line = 62084
vidicon_2_fill = 62085
vidicon_2_line = 62086
vidicon_fill = 62087
vidicon_line = 62088
vimeo_fill = 62089
vimeo_line = 62090
vip_crown_2_fill = 62091
vip_crown_2_line = 62092
vip_crown_fill = 62093
vip_crown_line = 62094
vip_diamond_fill = 62095
vip_diamond_line = 62096
vip_fill = 62097
vip_line = 62098
virus_fill = 62099
virus_line = 62100
visa_fill = 62101
visa_line = 62102
voice_recognition_fill = 62103
voice_recognition_line = 62104
voiceprint_fill = 62105
voiceprint_line = 62106
volume_down_fill = 62107
volume_down_line = 62108
volume_mute_fill = 62109
volume_mute_line = 62110
volume_off_vibrate_fill = 62111
volume_off_vibrate_line = 62112
volume_up_fill = 62113
volume_up_line = 62114
volume_vibrate_fill = 62115
volume_vibrate_line = 62116
vuejs_fill = 62117
vuejs_line = 62118
walk_fill = 62119
walk_line = 62120
wallet_2_fill = 62121
wallet_2_line = 62122
wallet_3_fill = 62123
wallet_3_line = 62124
wallet_fill = 62125
wallet_line = 62126
water_flash_fill = 62127
water_flash_line = 62128
webcam_fill = 62129
webcam_line = 62130
wechat_2_fill = 62131
wechat_2_line = 62132
wechat_fill = 62133
wechat_line = 62134
wechat_pay_fill = 62135
wechat_pay_line = 62136
weibo_fill = 62137
weibo_line = 62138
whatsapp_fill = 62139
whatsapp_line = 62140
wheelchair_fill = 62141
wheelchair_line = 62142
wifi_fill = 62143
wifi_line = 62144
wifi_off_fill = 62145
wifi_off_line = 62146
window_2_fill = 62147
window_2_line = 62148
window_fill = 62149
window_line = 62150
windows_fill = 62151
windows_line = 62152
windy_fill = 62153
windy_line = 62154
wireless_charging_fill = 62155
wireless_charging_line = 62156
women_fill = 62157
women_line = 62158
wubi_input = 62159
xbox_fill = 62160
xbox_line = 62161
xing_fill = 62162
xing_line = 62163
youtube_fill = 62164
youtube_line = 62165
zcool_fill = 62166
zcool_line = 62167
zhihu_fill = 62168
zhihu_line = 62169
zoom_in_fill = 62170
zoom_in_line = 62171
zoom_out_fill = 62172
zoom_out_line = 62173
zzz_fill = 62174
zzz_line = 62175



# from ..logging import DEBUGLOW2, log_func_call
from .constants import NODEFAULT, IS_WIN32
from .casesafe import (
    casesafe_dict_get, casesafe_dict_set, casesafe_key_in_dict,
)


# @log_func_call(DEBUGLOW2, trace_only=True)
def try_get_item(config: dict | list | tuple, key: str | int,
                 default=NODEFAULT, case_insensitive: bool = IS_WIN32):
    try:
        return casesafe_dict_get(config, key, default, case_insensitive)
    except TypeError:
        return try_get_item(config, int(key), default)
    except (KeyError, IndexError):
        return default


# @log_func_call(DEBUGLOW2, trace_only=True)
def config_dict_get(config: dict[str] | list | tuple, key: str,
                    default=NODEFAULT, case_insensitive: bool = IS_WIN32):
    """
    Get the value from a dict with given key.  If the key contains '.', it
    assumes that the key is a dot-delimited list of keys of nested dicts or
    lists, and will recursively drill down through the given "root" dict
    to return the ultimate value.

    Args:
        config (dict): dict (of nested dicts or lists) to search for key
        key (str): key to get from dict or dot-delimited list of keys
        default (Any, optional): Value to return if key not found.
           Defaults to NODEFAULT, which raises a KeyError if key is not found.

    Raises:
        KeyError: key not found in `config` or its nested children

    Returns:
        Any: value for key or default value (if provided)
    """
    parts = key.split('.', 1)
    part0 = parts[0]
    part1 = '.'.join(parts[1:])
    if hasattr(config, 'get'):
        value = casesafe_dict_get(config, part0, default, case_insensitive)

    elif hasattr(config, '__getitem__'):
        value = try_get_item(config, part0, default, case_insensitive)

    if part1 and hasattr(value, '__getitem__'):
        value = config_dict_get(value, part1, default, case_insensitive)

    if value is NODEFAULT:
        raise KeyError(key)
    return value


# @log_func_call(DEBUGLOW2, trace_only=True)
def config_dict_set(config: dict, key: str, value,
                    case_insensitive: bool = IS_WIN32):
    """
    Set the value in a dict with given key.  If the key contains '.', it
    assumes that the key is a dot-delimited list of keys of nested dicts or
    lists, and will recursively drill down through the given "root" dict
    to set the ultimate value.

    Args:
        config (dict): dict (of nested dicts or lists) to search for key to set
        key (str): key to set in dict or dot-delimited list of keys
        value (Any): Value to set
    """
    parts = key.split('.', 1)
    part0 = parts[0]
    part1 = '.'.join(parts[1:])
    if key == part0:
        casesafe_dict_set(config, key, value, case_insensitive)
    else:
        if not casesafe_key_in_dict(config, part0, case_insensitive):
            casesafe_dict_set(config, part0, dict(), case_insensitive)

        config_dict_set(config[part0], part1, value)


# @log_func_call(DEBUGLOW2, trace_only=True)
def config_dict_update(config: dict, data: dict,
                       case_insensitive: bool = IS_WIN32):
    """
    Update a dict with data from another dict.  The keys in incoming dict may
    be dot-delimited, indicating that the update will be performed recursively
    on any specified nested dicts or lists.

    Args:
        config (dict): dict (of nested dicts or lists) to update
        data (dict): incoming data to add/replace in `config` (recursively)
    """
    for k, v in data.items():
        config_dict_set(config, k, v, case_insensitive)



from ctypes import c_int, sizeof

from PySide2.QtCore import (  # noqa: F401
    qVersion,
    Qt,
    QRect,
    QObject,
    QEvent,
    QSize,
    QByteArray,
    QBuffer,
    QTimer,
    QRectF,
    QThread,
    QSizeF,
    QPointF,
    QPoint,
    QStringListModel,
    QSortFilterProxyModel,
    QItemSelection,
    QModelIndex,
)
from PySide2.QtGui import (  # noqa: F401
    QPixmap,
    QMouseEvent,
    QPalette,
    QCursor,
    QIcon,
    QPainter,
    QStandardItemModel,
    QStandardItem,
    QColor,
    QFont,
    QFontDatabase,
    QRawFont,
    QTransform,
    QImage,
    QIconEngine,
    QResizeEvent,
    QKeySequence,
    QFontMetrics,
    QFontMetricsF,
    QTextLayout,
    QTextOption,
)
from PySide2.QtWidgets import (  # noqa: F401
    QMainWindow,
    QWidget,
    QApplication,
    QDialog,
    QSplashScreen,
    QProgressBar,
    QLabel,
    QToolButton,
    QSlider,
    QAction,
    QSizePolicy,
    QFrame,
    QGraphicsView,
    QGraphicsScene,
    QVBoxLayout,
    QTreeView,
    QDialogButtonBox,
    QAbstractItemView,
    QListView,
    QToolBar,
    QComboBox,
    QLineEdit,
    QShortcut,
    QFileDialog,
    QStatusBar,
    QPushButton,
    QHBoxLayout,
    QMenuBar,
    QMenu,
    QStackedWidget,
    QTextEdit,
    QSplitter,
    QTreeWidget,
    QTreeWidgetItem,
    QTableWidget,
    QTableWidgetItem,
    QHeaderView,
    QAbstractButton,
    QMessageBox,
    QProgressDialog,
    QActionGroup,
    QStyleOptionViewItem,
    QStyledItemDelegate,
    QStyle,
    QItemDelegate,
)

# try:
#     # Needed since `QGlyphRun` is not available for PySide2
#     # See spyder-ide/qtawesome#210
#     from qtpy.QtGui import QGlyphRun
# except ImportError:
QGlyphRun = None

INT_SIZE = sizeof(c_int)
INT_MAX = 2**(INT_SIZE*8 - 1) - 1

# from src/gui/painting/qfixed_p.h
QFIXED_MAX = (INT_MAX//256)



import sys
from types import TracebackType, FrameType, ModuleType, CodeType, CellType
from typing import overload, TYPE_CHECKING, Any
from collections.abc import Callable, Mapping
from pathlib import Path
from inspect import getfile, getmodule, currentframe
from importlib import import_module
from logging import _srcfile
from traceback import StackSummary, FrameSummary, TracebackException
from itertools import islice
from linecache import (
    lazycache as lazylinecache, checkcache as checklinecache,
    getline as getcachedline
)
from textwrap import indent
if TYPE_CHECKING:
    from _typeshed import ReadableBuffer


SCRIPTPATH = Path(__file__)
STDLIB_LOGGING_SRCFILE = Path(_srcfile)
RUNPY_SRCFILE = (Path(sys.modules['runpy'].__file__) if 'runpy' in sys.modules
                 else None)
SHOW_TRACEBACK_LOCALS = None

ModAndName = tuple[ModuleType, str]
ExcInfoType = tuple[type, BaseException, TracebackType]


class AnnotatedFrameSummary(FrameSummary):
    pass


def set_show_traceback_locals(enabled: bool = True):
    global SHOW_TRACEBACK_LOCALS
    SHOW_TRACEBACK_LOCALS = bool(enabled)


def get_stack_frame(level: int = 1):
    __traceback_hide__ = True  # noqa: F841
    f = currentframe()
    for i in range(level):
        if f is None:
            raise ValueError(f"Stack frame level {level} does not exist.")
        f = f.f_back
    return f


def is_code_the_given_func(func: Callable, code: CodeType):
    qualname = getattr(code, 'co_qualname', None)
    bytecode = code.co_code
    match_code = False
    if not qualname:
        match_code = func.__code__.co_code == bytecode

    return qualname == func.__qualname__ if qualname else match_code


@overload
def get_module_and_name(modname: str = None) -> ModAndName: ...
@overload
def get_module_and_name(obj: object = None) -> ModAndName: ...
def get_module_and_name(arg=None):  # noqa: E302
    "returns mod, modname"
    mod = (import_module(arg) if isinstance(arg, str)
           else getmodule(arg or get_stack_frame(2)))
    return mod, mod.__name__ if mod else None


@overload
def top_module_and_name(modname: str = None) -> ModAndName: ...
@overload
def top_module_and_name(obj: object = None) -> ModAndName: ...
def top_module_and_name(arg=None):  # noqa: E302
    _, modname = get_module_and_name(arg or get_stack_frame(2))
    if modname:
        modname = modname.split('.')[0]
        try:
            return import_module(modname), modname
        except TypeError:
            pass

    return None, modname


@overload
def get_module_dir_path(modname: str = None) -> Path: ...
@overload
def get_module_dir_path(obj: object = None) -> Path: ...
def get_module_dir_path(arg=None):  # noqa: E302
    mod, modname = get_module_and_name(arg or get_stack_frame(2))
    try:
        return Path(getfile(mod)).parent
    except TypeError:
        if modname == '__main__':
            from .notebook import is_notebook
            # if it's not running in VSCode, idk my bff jill, why is this hard
            f = globals().get('__vsc_ipynb_file__') if is_notebook() else None
            if f:
                return Path(f).parent


@overload
def top_package_dir_path(modname: str = None) -> Path: ...
@overload
def top_package_dir_path(obj: object = None) -> Path: ...
def top_package_dir_path(arg=None):  # noqa: E302
    return get_module_dir_path(top_module_and_name(arg
                                                   or get_stack_frame(2))[0])


def is_internal_frame(frame: FrameSummary):
    __traceback_hide__ = True  # noqa: F841
    # adapted from stdlib logging._is_internal_frame
    filename = frame.filename
    p = Path(filename).resolve()
    loc = frame.locals or {}

    # tests broken out for debugging purposes
    testdict = dict(
        is_frozen=filename.startswith('<frozen '),
        is_stdlib_logging=p == STDLIB_LOGGING_SRCFILE,
        is_runpy=p == RUNPY_SRCFILE,
        # is_this_file=p == SCRIPTPATH,
        is_debugpy='debugpy' in p.parts,
        is_pydevd='pydevd' in p.parts,
        is_shiboken2='shiboken2' in p.parts,
        is_importlib_bootstrap=('importlib' == p.parent
                                and '_bootstrap' in p.name),
        is_traceback_hide=loc.get('__traceback_hide__')
    )
    internal = any(testdict.values())
    which = [k for k, v in testdict.items() if v] if internal else None  # noqa: E501, F841
    return internal


def get_framesummary_for_frame(f: FrameType, tb: TracebackType = None,
                               src: str = None, lineno: int = None):
    # adapted from stdlib traceback._walk_tb_with_full_positions
    # and from stdlib traceback.StackSummary._extract_from_extended_frame_gen
    __traceback_hide__ = True  # noqa: F841
    lasti = tb.tb_lasti if tb else f.f_lasti
    f_locals = f.f_locals
    code = f.f_code
    name = code.co_name
    filename = code.co_filename
    lazylinecache(filename, f.f_globals)
    checklinecache(filename)
    fixed_lineno = lineno
    if not lineno:
        lineno = None if lasti < 0 else (tb.tb_lineno if tb else f.f_lineno)

    posgen: Callable = (getattr(code, 'co_positions', None)
                        if fixed_lineno is None else None)
    underlines = bool(posgen)
    if posgen:
        lineno2, end_lineno, colno, end_colno = next(islice(posgen(),
                                                            lasti // 2, None))
        if lineno2 is not None:
            lineno = lineno2

    line = ((src.splitlines()[lineno - 1] if src else '<unknown source>')
            if filename == '<string>' else
            getcachedline(filename, lineno))
    if underlines:
        # I like seeing the underlines in the tracebacks, but if the issue is
        # the entire line, it doesn't print them.  As a hack, just lop off the
        # last character of the line.
        stripped_line = line.strip()
        striplen = len(stripped_line)
        endstriplen = len(line.rstrip())
        start_offset = byte_offset_to_character_offset(line, colno or 0)
        end_offset = byte_offset_to_character_offset(line, end_colno
                                                     or endstriplen)
        if lineno != end_lineno:
            # this is in traceback.StackSummary.format_frame_summary()
            # in Python 3.12.11, but probably is a bug?  It's not doing the
            # byte offset and just doing a raw line length...
            # which overrides the end_colno value.  Maybe this is correct
            # since it is supposed to be accounting for multiline blocks?
            # Either way, it's a problem for us since we are just printing
            # the first line, which may also not be correct.
            end_offset = endstriplen

        if end_offset - start_offset >= striplen:
            if lineno != end_lineno:
                # handles the "bug" above
                end_lineno = lineno

            # do this regardless
            end_colno = end_offset - 1

    kwargs = {
        'end_lineno': end_lineno,
        'colno': colno,
        'end_colno': end_colno
    } if posgen else {}

    summary = AnnotatedFrameSummary(filename, lineno, name, lookup_line=False,
                                    locals=f_locals, line=line, **kwargs)
    hide = f_locals.get('__traceback_hide_locals__', False)
    summary._pyrandyos_hide_locals = hide
    return summary


def build_stacksummary_for_frame(f: FrameType | None = None,
                                 reverse: bool = True):
    # adapted from stdlib traceback._walk_tb_with_full_positions
    # and from stdlib traceback.StackSummary._extract_from_extended_frame_gen
    __traceback_hide__ = True  # noqa: F841

    # If you want to limit the stack, you'll have to just slice the output
    # because I am removing the limits here to reduce complexity.
    result = StackSummary()
    f = f or get_stack_frame(2)
    while f is not None:
        result.append(get_framesummary_for_frame(f))
        f = f.f_back

    if reverse:
        result.reverse()

    return result


def build_stacksummary_for_tb(tb: TracebackType, exc: BaseException = None):
    # adapted from stdlib traceback._walk_tb_with_full_positions
    # and from stdlib traceback.StackSummary._extract_from_extended_frame_gen
    __traceback_hide__ = True  # noqa: F841

    # If you want to limit the stack, you'll have to just slice the output
    # because I am removing the limits here to reduce complexity.
    result = StackSummary()
    tb: TracebackType | None
    src: str = getattr(exc, '_pyrandyos_exec_source', '<unknown source>')
    src_f: FrameSummary = getattr(exc, '_pyrandyos_exec_source_frame', None)
    skipset = getattr(exc, '_pyrandyos_skip_next_reraise', None) or set()
    while tb is not None:
        fs = get_framesummary_for_frame(tb.tb_frame, tb, src)
        fs._pyrandyos_skip_next_reraise = id(tb) in skipset
        result.append(fs)
        tb = tb.tb_next

    if src_f:
        result.append(src_f)

    return result


def filter_stack(stk: StackSummary = None, stacklevel: int = 2):
    __traceback_hide__ = True  # noqa: F841
    # default stacklevel here is 2 since this is an absolute stacklevel
    # and we need to pop off the current frame and get_stack_frame.
    # We return the stack for the caller of this function immediately here
    # by default.
    stk = (stk or build_stacksummary_for_frame(get_stack_frame(stacklevel))
           or ())
    # return StackSummary.from_list([f for f in stk
    #                                if not is_internal_frame(f)])

    def stackgen():
        __traceback_hide__ = True  # noqa: F841
        last = None
        for f in stk:
            skip = getattr(f, '_pyrandyos_skip_next_reraise', False)
            if last and not skip:
                yield last

            if is_internal_frame(f):
                last = None
                continue

            last = f

        if last:
            yield last

    return StackSummary.from_list(list(stackgen()))


def byte_offset_to_character_offset(s: str, offset: int):
    __traceback_hide__ = True  # noqa: F841
    as_utf8 = s.encode('utf-8')
    return len(as_utf8[:offset].decode("utf-8", errors="replace"))


def get_real_caller_stack(stacklevel: int = 1):
    __traceback_hide__ = True  # noqa: F841
    f = get_stack_frame(1 + stacklevel)
    return build_stacksummary_for_frame(f, reverse=False) or ()


def filter_tb_stacksummary_if_not_internal(tb: TracebackType,
                                           exc: BaseException = None):
    __traceback_hide__ = True  # noqa: F841
    stk = build_stacksummary_for_tb(tb, exc)
    if stk:
        f = stk[-1]
        if not is_internal_frame(f):
            return filter_stack(stk)
    return stk


def log_find_caller(stack_info: bool = False, stacklevel: int = 1,
                    exc_info: ExcInfoType | None = None):
    __traceback_hide__ = True  # noqa: F841
    # stacklevel in this context is used to return the entry from the end
    # of the list from filter_stack when not given exc_info and building from
    # a traceback (in which case the stacklevel argument is effectively
    # ignored).  Because filter_stack automatically excludes __traceback_hide__
    # functions, including this one and likely any of its callers, we do NOT
    # need to apply an offset to the stack; the only reason for the default
    # stacklevel 1 is because it's actually a negative value and NOT because
    # it implies the need to pop more entries off of the stack.
    if exc_info:
        stk = filter_tb_stacksummary_if_not_internal(exc_info[2], exc_info[1])
        stacklevel = 0
    else:
        # with only default args here, filter_stack() will return a list
        # whose last element is the most recent caller that is NOT a hidden
        # function.  That means it will also exclude this current function.
        stk = filter_stack()

    if not stk:
        return "(unknown file)", 0, "(unknown function)", None
    f = stk[-stacklevel]
    sinfo = (f"Stack (most recent call last):\n{''.join(stk.format())}"
             if stack_info else None)
    return f.filename, f.lineno, f.name, sinfo


def filter_traceback_fullstack(tb: TracebackType, exc: BaseException):
    __traceback_hide__ = True  # noqa: F841
    tbstack = filter_tb_stacksummary_if_not_internal(tb, exc)
    stk = filter_stack(build_stacksummary_for_frame(tb.tb_frame))
    fullstack = StackSummary.from_list(stk[:-1] + tbstack)
    for f in fullstack:
        if SHOW_TRACEBACK_LOCALS or SHOW_TRACEBACK_LOCALS is None:
            # make a copy so we don't actually modify the frame
            loc = dict(f.locals)
            if loc:
                hide = f._pyrandyos_hide_locals
                if hide is True:
                    # remove locals from the stack frame
                    loc = None
                else:
                    if hide is False:
                        hide = ()

                    elif isinstance(hide, str):
                        hide = (hide,)

                    hide = set(('__builtins__',) + tuple(hide))
                    for n in hide:
                        if n in loc:
                            del loc[n]

            f.locals = loc
        else:
            # remove locals from the stack frames
            f.locals = None

    return fullstack


def add_src_note_to_traceback_exception(te: TracebackException,
                                        exc: BaseException,
                                        top_te: TracebackException = None):
    src = getattr(exc, '_pyrandyos_exec_source', None)
    if src:
        if hasattr(te, '__notes__'):
            noteattr = '__notes__'
            if not getattr(te, '__notes__', None):
                notelist = list()
                te.__notes__ = notelist

        else:
            te = top_te or te
            noteattr = '_pyrandyos_notes'

        notelist = getattr(te, noteattr, None)
        if notelist is None:
            notelist = list()
            setattr(te, noteattr, notelist)

        notelist.append("\n<string> code:\n" + indent(src, '    '))


def process_traceback_exception_pyrandyos_notes(te: TracebackException):
    return '\n'.join(getattr(te, '_pyrandyos_notes', ()))


def build_traceback_exception(exc: BaseException | TracebackException,
                              tb: TracebackType = None, compact: bool = False):
    __traceback_hide__ = True  # noqa: F841

    seen = set()
    seen.add(id(exc))

    tb = tb or exc.__traceback__
    te = (exc if isinstance(exc, TracebackException)
          else TracebackException(type(exc), exc, tb, compact=compact))
    te.stack = filter_traceback_fullstack(tb, exc)
    add_src_note_to_traceback_exception(te, exc)
    top_te = te

    queue = [(te, exc)]
    while queue:
        te, exc = queue.pop()
        te_cause = te.__cause__
        exc_cause = exc.__cause__ if te_cause else None
        exc_cause_id = id(exc_cause)
        if te_cause and exc_cause_id not in seen:
            seen.add(exc_cause_id)
            tb = exc_cause.__traceback__
            te_cause.stack = filter_traceback_fullstack(tb, exc_cause)
            add_src_note_to_traceback_exception(te_cause, exc_cause)
            queue.append((te_cause, exc_cause))

        te_context = te.__context__
        exc_context = exc.__context__ if te_context else None
        exc_context_id = id(exc_context)
        if te_context and exc_context_id not in seen:
            seen.add(exc_context_id)
            tb = exc_context.__traceback__
            te_context.stack = filter_traceback_fullstack(tb, exc_context)
            add_src_note_to_traceback_exception(te_context, exc_context)
            queue.append((te_context, exc_context))

        te_exceptions = getattr(te, 'exceptions', None)
        if te_exceptions:
            exc_exceptions = exc.exceptions
            for i, e in enumerate(exc_exceptions):
                e_id = id(e)
                if e_id not in seen:
                    seen.add(e_id)
                    tb = e.__traceback__
                    te_exceptions[i].stack = filter_traceback_fullstack(tb, e)
                    add_src_note_to_traceback_exception(te_exceptions[i], e)

            queue.extend(zip(te_exceptions, exc_exceptions))

    return top_te


def format_exc(exc: BaseException, tb: TracebackType = None):
    __traceback_hide__ = True  # noqa: F841
    te = build_traceback_exception(exc, tb)
    s = ''.join(te.format())
    s += process_traceback_exception_pyrandyos_notes(te)
    return s


def exc_info(exc_or_type: type | BaseException | ExcInfoType = None,
             exc: BaseException | None = None,
             traceback: TracebackType = None, skip_if_none: bool = False):
    __traceback_hide__ = True  # noqa: F841
    if skip_if_none and not any((exc_or_type, exc, traceback)):
        return
    if isinstance(exc_or_type, tuple):
        exc_or_type, exc, traceback = exc_or_type

    if isinstance(exc_or_type, BaseException):
        exc = exc_or_type
        exc_or_type = None

    if exc:
        exc_or_type = exc_or_type or type(exc)
        traceback = traceback or exc.__traceback__

    else:
        exc_or_type, exc, traceback = sys.exc_info()

    return exc_or_type, exc, traceback


def safe_exec(source: 'str | ReadableBuffer | CodeType',
              globals_: dict[str, Any] | None = None,
              locals_: Mapping[str, object] | None = None,
              /, *,
              closure: tuple[CellType, ...] | None = None,
              src_frame: FrameType = None,
              log_errors: bool = True):
    """
    Safely execute a Python source code string in the given environment.

    Args:
        src (str): The Python source code to execute.
        globals (dict): The global environment in which to execute the code.
        locals (dict): The local environment in which to execute the code.

    Raises:
        Exception: If there is an error during execution.
    """
    __traceback_hide__ = True  # noqa: F841
    __traceback_hide_locals__ = True  # noqa: F841
    kw = {'closure': closure} if sys.version_info >= (3, 11) else {}
    try:
        exec(source, globals_, locals_, **kw)
    except BaseException as e:
        e._pyrandyos_exec_source = source
        e._pyrandyos_exec_source_frame = src_frame
        # the next frame here will just be re-raising, so skip it
        mark_next_tb_reraise_to_skip(e)
        if log_errors:
            try:
                from ..logging import log_exc
            except ImportError:
                pass
            else:
                log_exc(e)

        raise e


def mark_next_tb_reraise_to_skip(exc: BaseException):
    """
    Skip the last re-raise in the traceback of an exception.
    This is useful for cleaning up tracebacks that have been modified
    by decorators or other code that re-raises exceptions.
    """
    __traceback_hide__ = True  # noqa: F841
    # the next frame here is just re-raising, so skip it
    # tb.tb_next = tb.tb_next.tb_next
    skipset = getattr(exc, '_pyrandyos_skip_next_reraise', None) or set()
    skipset.add(id(exc.__traceback__))
    exc._pyrandyos_skip_next_reraise = skipset



class TupleHashMixin:
    def as_tuple(self):
        raise NotImplementedError("Subclasses must implement as_tuple()")

    def __eq__(self, other):
        if not isinstance(other, type(self)):
            return NotImplemented
        return self.as_tuple() == other.as_tuple()

    def __hash__(self):
        return hash(self.as_tuple())



"""
This module is intended for internal use only.  No user documentation is
provided at this time.  Use at your own discretion.
"""
from pathlib import Path
from shutil import chown
from datetime import datetime
from logging import (
    LogRecord, basicConfig, DEBUG, INFO, StreamHandler, Formatter, getLogger,
    CRITICAL, ERROR, WARNING, FileHandler, Logger, addLevelName,
    Handler,
)
from logging.handlers import MemoryHandler

from ..logging import (
    DEBUGLOW2, log_func_call, LOGSTDOUT, LOGSTDERR, LOGTQDM,
    APP_LOG_LEVEL_NAMES, get_loglevel_num_name
)
from .constants import DEFAULT_GROUP, DEFAULT_DIR_MODE
from .constants.cli import ConsoleText

_LOGCACHE: MemoryHandler = None


class MillisecondFormatter(Formatter):
    default_msec_format = '%s.%03d'


class LogMultiFormatter(Formatter):
    def __init__(self, fmtdict: dict[str | int, Formatter], **kwargs):
        super().__init__(**kwargs)
        self.fmtdict = fmtdict

    def format(self, record: LogRecord):
        return self.fmtdict.get(record.levelno,
                                self.fmtdict['DEFAULT']).format(record)


class LevelFilter:
    def __init__(self, level: int):
        self.__level = level

    def filter(self, record: LogRecord):
        return record.levelno >= self.__level


# debugfmtstr = '%(asctime)s::%(name)s::%(pathname)s::%(funcName)s(%(lineno)d)::%(levelname)s::%(message)s'  # noqa: E501
debugfmtstr = '%(asctime)s | %(levelname)s | %(pathname)s(%(lineno)d) | %(funcName)s | %(message)s'  # noqa: E501
debug_ms_fmt = MillisecondFormatter(debugfmtstr)
simple_color_fmt = LogMultiFormatter({
    INFO: MillisecondFormatter(ConsoleText.GreenText
                               + "%(message)s"
                               + ConsoleText.Reset),
    LOGSTDOUT: MillisecondFormatter(ConsoleText.WhiteText
                                    + "%(message)s"
                                    + ConsoleText.Reset),
    LOGSTDERR: MillisecondFormatter(ConsoleText.CyanText
                                    + "%(message)s"
                                    + ConsoleText.Reset),
    LOGTQDM: MillisecondFormatter(ConsoleText.BlueText
                                  + "%(message)s"
                                  + ConsoleText.Reset),
    WARNING: MillisecondFormatter(ConsoleText.YellowText
                                  + "%(asctime)s %(levelname)s: %(message)s"
                                  + ConsoleText.Reset),
    ERROR: MillisecondFormatter(ConsoleText.RedText
                                + "%(asctime)s %(levelname)s: %(message)s"
                                + ConsoleText.Reset),
    CRITICAL: MillisecondFormatter(ConsoleText.MagentaText
                                   + "%(asctime)s %(levelname)s: %(message)s"
                                   + ConsoleText.Reset),
    'DEFAULT': MillisecondFormatter("%(asctime)s %(levelname)s: %(message)s"),
})


@log_func_call
def create_cli_log_handler(level: int | str = INFO,
                           fmt: Formatter = simple_color_fmt):
    if isinstance(level, str):
        level = level.upper()

    clilog = StreamHandler()
    check_loglevel(level)
    clilog.setLevel(level)
    clilog.setFormatter(fmt)
    return clilog


@log_func_call
def create_file_log_handler(logfile: Path, level: int | str = DEBUG,
                            fmt: Formatter = debug_ms_fmt):
    if isinstance(level, str):
        level = level.upper()

    # filelog = FileHandler(logfile, errors='backslashreplace')
    filelog = FileHandler(logfile, encoding='utf-8', errors='backslashreplace')
    check_loglevel(level)
    filelog.setLevel(level)
    filelog.setFormatter(fmt)
    return filelog


@log_func_call
def create_memory_log_handler(buffer: int = 1024, level: int | str = 0,
                              fmt: Formatter = debug_ms_fmt):
    if isinstance(level, str):
        level = level.upper()

    memlog = MemoryHandler(buffer)
    check_loglevel(level)
    memlog.setLevel(level)
    memlog.setFormatter(fmt)
    return memlog


@log_func_call
def setup_memory_logging(cli_log_level: int | str = INFO,
                         force: bool = False, cli: bool = True,
                         logger: Logger = None):
    global _LOGCACHE
    _LOGCACHE = create_memory_log_handler()
    handlers = [_LOGCACHE]
    if cli:
        handlers.append(create_cli_log_handler(cli_log_level))
    basicConfig(force=force, level=0, handlers=handlers)
    log = logger or getLogger(__name__)
    log.debug('setup_memory_logging complete')


@log_func_call
def setup_logging(logfile: Path = None, cli_log_level: int | str = INFO,
                  file_log_level: int | str = DEBUG,
                  force: bool = True, cli: bool = True,
                  logger: Logger = None):
    global _LOGCACHE
    handlers: list[Handler] = list()
    filt = None
    if logger:
        if _LOGCACHE:
            for h in logger.handlers:
                if isinstance(h, FileHandler):
                    _LOGCACHE.setTarget(h)
                    filt = LevelFilter(h.level)
                    h.addFilter(filt)
                    _LOGCACHE.flush()
                    # h.removeFilter(filt)
                    break
    elif logfile:
        filelog: FileHandler = create_file_log_handler(logfile, file_log_level)
        handlers.append(filelog)
        if _LOGCACHE:
            _LOGCACHE.setTarget(filelog)
            filt = LevelFilter(filelog.level)
            filelog.addFilter(filt)
            _LOGCACHE.flush()
            # filelog.removeFilter(filt)

    if cli:
        handlers.append(create_cli_log_handler(cli_log_level))

    if handlers:
        basicConfig(force=force, level=0, handlers=handlers)

    if _LOGCACHE:
        _LOGCACHE.flush()
        if filt:
            for h in handlers:
                h.removeFilter(filt)

        _LOGCACHE = None

    log = logger or getLogger(__name__)
    log.debug('setup_logging complete')


@log_func_call(DEBUGLOW2)
def is_valid_loglevel(level: str | int):
    if isinstance(level, int):
        return True
    try:
        _, name = get_loglevel_num_name(level)
    except ValueError:
        return False
    return name is not None


@log_func_call(DEBUGLOW2)
def add_loglevel_name(logname: str, loglevel: str | int):
    num, name = get_loglevel_num_name(loglevel)
    if name is None:
        addLevelName(num, logname)


@log_func_call(DEBUGLOW2)
def check_loglevel(level: str | int):
    if is_valid_loglevel(level):
        return
    level = level.upper()
    if level not in APP_LOG_LEVEL_NAMES:
        raise ValueError(f'unknown loglevel string {level} given')
    add_loglevel_name(level, APP_LOG_LEVEL_NAMES[level])


for k in APP_LOG_LEVEL_NAMES.keys():
    check_loglevel(k)


@log_func_call
def create_log_file(logdir: Path, timestamp_name: bool = True,
                    append: bool = False, prefix: str = 'log',
                    group: str = DEFAULT_GROUP, mode: int = DEFAULT_DIR_MODE,
                    suffix: str = '.log'):
    logdir.mkdir(exist_ok=True, parents=True, mode=mode)
    if group:
        chown(logdir, group=group)

    stem = prefix
    if timestamp_name:
        now_ymdhms = datetime.now().timetuple()[:6]
        y = f"{now_ymdhms[0]:04}"
        mon = f"{now_ymdhms[1]:02}"
        d = f"{now_ymdhms[2]:02}"
        h = f"{now_ymdhms[3]:02}"
        m = f"{now_ymdhms[4]:02}"
        s = f"{now_ymdhms[5]:02.0f}"
        stem = f'{stem}_{y}{mon}{d}T{h}{m}{s}'

    logfile = logdir/f'{stem}{suffix}'
    if not append:
        logfile.write_text('')

    return logfile



############
# FIXED KEYS
#
# What is ironic is that I titled this section in all caps, but this note is
# here to say that all fixed keys should always be lowercase.

# bootstrap keys
BASE_PATH_KEY = 'base_path'  # not included in PATH_KEYS, handle manually
ABS_BASE_PATH_KEY = 'base_path:abs'  # not included in PATH_KEYS
BASE_LOG_DIR_KEY = 'log_dir'
TMP_DIR_KEY = 'tmp_dir'
LOG_TIMESTAMP_KEY = 'log_timestamp_name'
APPEND_LOG_KEY = 'append_log'
CLI_LOG_LEVEL_KEY = 'cli_log_level'
FILE_LOG_LEVEL_KEY = 'file_log_level'
STATUSBAR_LOG_LEVEL_KEY = 'statusbar_log_level'
LOCAL_CONFIG_FILE_KEY = 'local_config_file'
LOG_TRACE_ENABLED_KEY = 'log_trace_enabled'
LOG_FUNC_CALL_ENABLED_KEY = 'log_func_call_enabled'
SHOW_TRACEBACK_LOCALS_KEY = 'show_traceback_locals'
LOCAL_CFG_KEY = 'local'
QRC_FILE_KEY = 'qrc_file'
QRC_PYFILE_KEY = 'qrc_pyfile'
# not included in PATH_KEYS since this is internal only
BASE_LOG_PATH_KEY = '__log_path'

# other fixed keys
APP_NAME_KEY = 'app_name'
APP_PKG_DIR_KEY = 'package_dir'
APP_PKG_VERSION_KEY = 'package_version'
APP_ASSETS_DIR_KEY = 'assets_dir'
CONFIG_PACKAGE_DIR_KEY = 'config_package_dir'
CONFIG_PACKAGE_VERSION_KEY = 'config_package_version'

PATH_KEYS = (
    BASE_LOG_DIR_KEY,
    TMP_DIR_KEY,
    APP_PKG_DIR_KEY,
    APP_ASSETS_DIR_KEY,
    QRC_PYFILE_KEY,
    QRC_FILE_KEY,

    # "local.delivery_config_dir",
    LOCAL_CONFIG_FILE_KEY,
)
LOGDIRKEYS = (
    BASE_LOG_DIR_KEY,
)

# END FIXED KEYS
################


def get_path_keys(app_path_keys: tuple[str] = ()):
    return PATH_KEYS + app_path_keys


def get_log_dir_keys(app_log_dir_keys: tuple[str] = ()):
    return LOGDIRKEYS + app_log_dir_keys



import sys
from getpass import getuser

IS_WIN32 = sys.platform == "win32"

NODEFAULT = object()
"""
Sentinel constant to indicate no default value was given to a
`get()`-like function, such as `config_dict_get()`
"""

USER = getuser()
DEFAULT_GROUP = None if IS_WIN32 else USER
DEFAULT_DIR_MODE = 0o2750
DEFAULT_FILE_MODE = 0o640



from re import sub, DOTALL, MULTILINE, compile
from collections import OrderedDict

from ...logging import log_func_call


@log_func_call
def strip_qss_comments(qss: str) -> str:
    """Remove /* ... */ comments from QSS string."""
    return sub(r'/\*.*?\*/', '', qss, flags=DOTALL)


@log_func_call
def parse_qss_blocks(qss_text: str) -> OrderedDict:
    """Parse QSS into an OrderedDict: selector -> OrderedDict of properties."""
    blocks = OrderedDict()
    pattern = compile(r'([^{]+)\{([^}]*)\}', MULTILINE)
    # This regex matches key: value; pairs, where value can include semicolons
    # inside quotes
    import re
    prop_pattern = re.compile(r'([a-zA-Z0-9\-]+)\s*:\s*((?:"[^"]*"|[^;])*);')
    for match in pattern.finditer(qss_text):
        selector = match.group(1).strip()
        props = OrderedDict()
        for prop_match in prop_pattern.finditer(match.group(2)):
            k = prop_match.group(1).strip()
            v = prop_match.group(2).strip()
            props[k] = v
        blocks[selector] = props
    return blocks


@log_func_call
def update_qss_block(blocks: OrderedDict, selector: str,
                     updates: dict[str, str]) -> None:
    """Update or add properties for a selector in the QSS blocks.

    To remove a property, pass None as the value.
    """
    if selector not in blocks:
        blocks[selector] = OrderedDict()
    for k, v in updates.items():
        if v is None:
            # Remove the property if it exists
            blocks[selector].pop(k, None)
        else:
            # Set or update the property
            blocks[selector][k] = v


@log_func_call
def qss_blocks_to_text(blocks: OrderedDict) -> str:
    """Convert QSS blocks back to a QSS string."""
    out = []
    for selector, props in blocks.items():
        out.append(f"{selector} {{")
        for k, v in props.items():
            out.append(f"    {k}: {v};")
        out.append("}")
    return "\n".join(out)


@log_func_call
def merge_qss_properties(qss: str, selector: str, updates: dict[str, str]):
    """
    Load QSS, strip comments, parse, update properties for selector, and return
    merged QSS string.
    """
    qss = strip_qss_comments(qss)
    blocks = parse_qss_blocks(qss)
    update_qss_block(blocks, selector, updates)
    return qss_blocks_to_text(blocks)

# Example usage:
# with open("vibedark-full.qss", "r", encoding="utf-8") as f:
#     qss = f.read()
# merged_qss = merge_qss_properties(qss, "QComboBox::down-arrow", {
#     "image": 'url("data:image/png;base64,...")',
#     "width": "16px",
#     "height": "16px"
# })
# app.setStyleSheet(merged_qss)
